from ...tl.mtproto_request import MTProtoRequest


class TextUnderline(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    textUnderline#c12622c4 text:RichText = RichText"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xc12622c4

    def __init__(self, text):
        """
        :param text: Telegram type: «RichText».

        Constructor for RichText: Instance of either TextEmpty, TextPlain, TextBold, TextItalic, TextUnderline, TextStrike, TextFixed, TextUrl, TextEmail, TextConcat.
        """
        super().__init__()

        self.text = text

    def on_send(self, writer):
        writer.write_int(TextUnderline.constructor_id, signed=False)
        self.text.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return TextUnderline(None)

    def on_response(self, reader):
        self.text = reader.tgread_object()

    def __repr__(self):
        return 'textUnderline#c12622c4 text:RichText = RichText'

    def __str__(self):
        return '(textUnderline (ID: 0xc12622c4) = (text={}))'.format(str(self.text))



from ...tl.mtproto_request import MTProtoRequest


class CdnConfig(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    cdnConfig#5725e40a public_keys:Vector<CdnPublicKey> = CdnConfig"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x5725e40a

    def __init__(self, public_keys):
        """
        :param public_keys: Telegram type: «CdnPublicKey». Must be a list.

        Constructor for CdnConfig: Instance of CdnConfig.
        """
        super().__init__()

        self.public_keys = public_keys

    def on_send(self, writer):
        writer.write_int(CdnConfig.constructor_id, signed=False)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.public_keys))
        for public_keys_item in self.public_keys:
            public_keys_item.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return CdnConfig(None)

    def on_response(self, reader):
        reader.read_int()  # Vector's constructor ID
        self.public_keys = []  # Initialize an empty list
        public_keys_len = reader.read_int()
        for _ in range(public_keys_len):
            public_keys_item = reader.tgread_object()
            self.public_keys.append(public_keys_item)

    def __repr__(self):
        return 'cdnConfig#5725e40a public_keys:Vector<CdnPublicKey> = CdnConfig'

    def __str__(self):
        return '(cdnConfig (ID: 0x5725e40a) = (public_keys={}))'.format(None if not self.public_keys else [str(_) for _ in self.public_keys])



from ....tl.mtproto_request import MTProtoRequest


class DiscardCallRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    phone.discardCall#78d413a6 peer:InputPhoneCall duration:int reason:PhoneCallDiscardReason connection_id:long = Updates"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x78d413a6

    def __init__(self, peer, duration, reason, connection_id):
        """
        :param peer: Telegram type: «InputPhoneCall».
        :param duration: Telegram type: «int».
        :param reason: Telegram type: «PhoneCallDiscardReason».
        :param connection_id: Telegram type: «long».

        :returns Updates: Instance of either UpdatesTooLong, UpdateShortMessage, UpdateShortChatMessage, UpdateShort, UpdatesCombined, UpdatesTg, UpdateShortSentMessage.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.peer = peer
        self.duration = duration
        self.reason = reason
        self.connection_id = connection_id

    def on_send(self, writer):
        writer.write_int(DiscardCallRequest.constructor_id, signed=False)
        self.peer.on_send(writer)
        writer.write_int(self.duration)
        self.reason.on_send(writer)
        writer.write_long(self.connection_id)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return DiscardCallRequest(None, None, None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'phone.discardCall#78d413a6 peer:InputPhoneCall duration:int reason:PhoneCallDiscardReason connection_id:long = Updates'

    def __str__(self):
        return '(phone.discardCall (ID: 0x78d413a6) = (peer={}, duration={}, reason={}, connection_id={}))'.format(str(self.peer), str(self.duration), str(self.reason), str(self.connection_id))



from ...tl.mtproto_request import MTProtoRequest


class Invoice(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    invoice#c30aa358 flags:# test:flags.0?true name_requested:flags.1?true phone_requested:flags.2?true email_requested:flags.3?true shipping_address_requested:flags.4?true flexible:flags.5?true currency:string prices:Vector<LabeledPrice> = Invoice"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xc30aa358

    def __init__(self, currency, prices, test=None, name_requested=None, phone_requested=None, email_requested=None, shipping_address_requested=None, flexible=None):
        """
        :param test: Telegram type: «true».
        :param name_requested: Telegram type: «true».
        :param phone_requested: Telegram type: «true».
        :param email_requested: Telegram type: «true».
        :param shipping_address_requested: Telegram type: «true».
        :param flexible: Telegram type: «true».
        :param currency: Telegram type: «string».
        :param prices: Telegram type: «LabeledPrice». Must be a list.

        Constructor for Invoice: Instance of Invoice.
        """
        super().__init__()

        self.test = test
        self.name_requested = name_requested
        self.phone_requested = phone_requested
        self.email_requested = email_requested
        self.shipping_address_requested = shipping_address_requested
        self.flexible = flexible
        self.currency = currency
        self.prices = prices

    def on_send(self, writer):
        writer.write_int(Invoice.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.test else 0
        flags |= (1 << 1) if self.name_requested else 0
        flags |= (1 << 2) if self.phone_requested else 0
        flags |= (1 << 3) if self.email_requested else 0
        flags |= (1 << 4) if self.shipping_address_requested else 0
        flags |= (1 << 5) if self.flexible else 0
        writer.write_int(flags)

        writer.tgwrite_string(self.currency)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.prices))
        for prices_item in self.prices:
            prices_item.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return Invoice(None, None, None, None, None, None, None, None)

    def on_response(self, reader):
        flags = reader.read_int()

        if (flags & (1 << 0)) != 0:
            self.test = True  # Arbitrary not-None value, no need to read since it is a flag

        if (flags & (1 << 1)) != 0:
            self.name_requested = True  # Arbitrary not-None value, no need to read since it is a flag

        if (flags & (1 << 2)) != 0:
            self.phone_requested = True  # Arbitrary not-None value, no need to read since it is a flag

        if (flags & (1 << 3)) != 0:
            self.email_requested = True  # Arbitrary not-None value, no need to read since it is a flag

        if (flags & (1 << 4)) != 0:
            self.shipping_address_requested = True  # Arbitrary not-None value, no need to read since it is a flag

        if (flags & (1 << 5)) != 0:
            self.flexible = True  # Arbitrary not-None value, no need to read since it is a flag

        self.currency = reader.tgread_string()
        reader.read_int()  # Vector's constructor ID
        self.prices = []  # Initialize an empty list
        prices_len = reader.read_int()
        for _ in range(prices_len):
            prices_item = reader.tgread_object()
            self.prices.append(prices_item)

    def __repr__(self):
        return 'invoice#c30aa358 flags:# test:flags.0?true name_requested:flags.1?true phone_requested:flags.2?true email_requested:flags.3?true shipping_address_requested:flags.4?true flexible:flags.5?true currency:string prices:Vector<LabeledPrice> = Invoice'

    def __str__(self):
        return '(invoice (ID: 0xc30aa358) = (test={}, name_requested={}, phone_requested={}, email_requested={}, shipping_address_requested={}, flexible={}, currency={}, prices={}))'.format(str(self.test), str(self.name_requested), str(self.phone_requested), str(self.email_requested), str(self.shipping_address_requested), str(self.flexible), str(self.currency), None if not self.prices else [str(_) for _ in self.prices])



from ....tl.mtproto_request import MTProtoRequest


class FileCdnRedirect(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    upload.fileCdnRedirect#1508485a dc_id:int file_token:bytes encryption_key:bytes encryption_iv:bytes = upload.File"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x1508485a

    def __init__(self, dc_id, file_token, encryption_key, encryption_iv):
        """
        :param dc_id: Telegram type: «int».
        :param file_token: Telegram type: «bytes».
        :param encryption_key: Telegram type: «bytes».
        :param encryption_iv: Telegram type: «bytes».

        Constructor for upload.File: Instance of either File, FileCdnRedirect.
        """
        super().__init__()

        self.dc_id = dc_id
        self.file_token = file_token
        self.encryption_key = encryption_key
        self.encryption_iv = encryption_iv

    def on_send(self, writer):
        writer.write_int(FileCdnRedirect.constructor_id, signed=False)
        writer.write_int(self.dc_id)
        writer.tgwrite_bytes(self.file_token)
        writer.tgwrite_bytes(self.encryption_key)
        writer.tgwrite_bytes(self.encryption_iv)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return FileCdnRedirect(None, None, None, None)

    def on_response(self, reader):
        self.dc_id = reader.read_int()
        self.file_token = reader.tgread_bytes()
        self.encryption_key = reader.tgread_bytes()
        self.encryption_iv = reader.tgread_bytes()

    def __repr__(self):
        return 'upload.fileCdnRedirect#1508485a dc_id:int file_token:bytes encryption_key:bytes encryption_iv:bytes = upload.File'

    def __str__(self):
        return '(upload.fileCdnRedirect (ID: 0x1508485a) = (dc_id={}, file_token={}, encryption_key={}, encryption_iv={}))'.format(str(self.dc_id), str(self.file_token), str(self.encryption_key), str(self.encryption_iv))



from ...tl.mtproto_request import MTProtoRequest


class UpdateChatParticipants(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateChatParticipants#07761198 participants:ChatParticipants = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x7761198

    def __init__(self, participants):
        """
        :param participants: Telegram type: «ChatParticipants».

        Constructor for Update: Instance of either UpdateNewMessage, UpdateMessageID, UpdateDeleteMessages, UpdateUserTyping, UpdateChatUserTyping, UpdateChatParticipants, UpdateUserStatus, UpdateUserName, UpdateUserPhoto, UpdateContactRegistered, UpdateContactLink, UpdateNewEncryptedMessage, UpdateEncryptedChatTyping, UpdateEncryption, UpdateEncryptedMessagesRead, UpdateChatParticipantAdd, UpdateChatParticipantDelete, UpdateDcOptions, UpdateUserBlocked, UpdateNotifySettings, UpdateServiceNotification, UpdatePrivacy, UpdateUserPhone, UpdateReadHistoryInbox, UpdateReadHistoryOutbox, UpdateWebPage, UpdateReadMessagesContents, UpdateChannelTooLong, UpdateChannel, UpdateNewChannelMessage, UpdateReadChannelInbox, UpdateDeleteChannelMessages, UpdateChannelMessageViews, UpdateChatAdmins, UpdateChatParticipantAdmin, UpdateNewStickerSet, UpdateStickerSetsOrder, UpdateStickerSets, UpdateSavedGifs, UpdateBotInlineQuery, UpdateBotInlineSend, UpdateEditChannelMessage, UpdateChannelPinnedMessage, UpdateBotCallbackQuery, UpdateEditMessage, UpdateInlineBotCallbackQuery, UpdateReadChannelOutbox, UpdateDraftMessage, UpdateReadFeaturedStickers, UpdateRecentStickers, UpdateConfig, UpdatePtsChanged, UpdateChannelWebPage, UpdateDialogPinned, UpdatePinnedDialogs, UpdateBotWebhookJSON, UpdateBotWebhookJSONQuery, UpdateBotShippingQuery, UpdateBotPrecheckoutQuery, UpdatePhoneCall.
        """
        super().__init__()

        self.participants = participants

    def on_send(self, writer):
        writer.write_int(UpdateChatParticipants.constructor_id, signed=False)
        self.participants.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateChatParticipants(None)

    def on_response(self, reader):
        self.participants = reader.tgread_object()

    def __repr__(self):
        return 'updateChatParticipants#07761198 participants:ChatParticipants = Update'

    def __str__(self):
        return '(updateChatParticipants (ID: 0x7761198) = (participants={}))'.format(str(self.participants))



from ....tl.mtproto_request import MTProtoRequest


class UpdateProfileRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    account.updateProfile#78515775 flags:# first_name:flags.0?string last_name:flags.1?string about:flags.2?string = User"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x78515775

    def __init__(self, first_name=None, last_name=None, about=None):
        """
        :param first_name: Telegram type: «string».
        :param last_name: Telegram type: «string».
        :param about: Telegram type: «string».

        :returns User: Instance of either UserEmpty, User.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.first_name = first_name
        self.last_name = last_name
        self.about = about

    def on_send(self, writer):
        writer.write_int(UpdateProfileRequest.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.first_name else 0
        flags |= (1 << 1) if self.last_name else 0
        flags |= (1 << 2) if self.about else 0
        writer.write_int(flags)

        if self.first_name:
            writer.tgwrite_string(self.first_name)

        if self.last_name:
            writer.tgwrite_string(self.last_name)

        if self.about:
            writer.tgwrite_string(self.about)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateProfileRequest(None, None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'account.updateProfile#78515775 flags:# first_name:flags.0?string last_name:flags.1?string about:flags.2?string = User'

    def __str__(self):
        return '(account.updateProfile (ID: 0x78515775) = (first_name={}, last_name={}, about={}))'.format(str(self.first_name), str(self.last_name), str(self.about))



from .res_pq import ResPQ
from .p_q_inner_data import PQInnerData
from .server_dh_params_fail import ServerDHParamsFail
from .server_dh_params_ok import ServerDHParamsOk
from .server_dh_inner_data import ServerDHInnerData
from .client_dh_inner_data import ClientDHInnerData
from .dh_gen_ok import DhGenOk
from .dh_gen_retry import DhGenRetry
from .dh_gen_fail import DhGenFail
from .destroy_auth_key_ok import DestroyAuthKeyOk
from .destroy_auth_key_none import DestroyAuthKeyNone
from .destroy_auth_key_fail import DestroyAuthKeyFail
from .msgs_ack import MsgsAck
from .bad_msg_notification import BadMsgNotification
from .bad_server_salt import BadServerSalt
from .msgs_state_req import MsgsStateReq
from .msgs_state_info import MsgsStateInfo
from .msgs_all_info import MsgsAllInfo
from .msg_detailed_info import MsgDetailedInfo
from .msg_new_detailed_info import MsgNewDetailedInfo
from .msg_resend_req import MsgResendReq
from .rpc_error import RpcError
from .rpc_answer_unknown import RpcAnswerUnknown
from .rpc_answer_dropped_running import RpcAnswerDroppedRunning
from .rpc_answer_dropped import RpcAnswerDropped
from .future_salt import FutureSalt
from .future_salts import FutureSalts
from .pong import Pong
from .destroy_session_ok import DestroySessionOk
from .destroy_session_none import DestroySessionNone
from .new_session_created import NewSessionCreated
from .http_wait import HttpWait
from .error import Error
from .null import Null
from .input_peer_empty import InputPeerEmpty
from .input_peer_self import InputPeerSelf
from .input_peer_chat import InputPeerChat
from .input_peer_user import InputPeerUser
from .input_peer_channel import InputPeerChannel
from .input_user_empty import InputUserEmpty
from .input_user_self import InputUserSelf
from .input_user import InputUser
from .input_phone_contact import InputPhoneContact
from .input_file import InputFile
from .input_file_big import InputFileBig
from .input_media_empty import InputMediaEmpty
from .input_media_uploaded_photo import InputMediaUploadedPhoto
from .input_media_photo import InputMediaPhoto
from .input_media_geo_point import InputMediaGeoPoint
from .input_media_contact import InputMediaContact
from .input_media_uploaded_document import InputMediaUploadedDocument
from .input_media_uploaded_thumb_document import InputMediaUploadedThumbDocument
from .input_media_document import InputMediaDocument
from .input_media_venue import InputMediaVenue
from .input_media_gif_external import InputMediaGifExternal
from .input_media_photo_external import InputMediaPhotoExternal
from .input_media_document_external import InputMediaDocumentExternal
from .input_media_game import InputMediaGame
from .input_media_invoice import InputMediaInvoice
from .input_chat_photo_empty import InputChatPhotoEmpty
from .input_chat_uploaded_photo import InputChatUploadedPhoto
from .input_chat_photo import InputChatPhoto
from .input_geo_point_empty import InputGeoPointEmpty
from .input_geo_point import InputGeoPoint
from .input_photo_empty import InputPhotoEmpty
from .input_photo import InputPhoto
from .input_file_location import InputFileLocation
from .input_encrypted_file_location import InputEncryptedFileLocation
from .input_document_file_location import InputDocumentFileLocation
from .input_app_event import InputAppEvent
from .peer_user import PeerUser
from .peer_chat import PeerChat
from .peer_channel import PeerChannel
from .file_location_unavailable import FileLocationUnavailable
from .file_location import FileLocation
from .user_empty import UserEmpty
from .user import User
from .user_profile_photo_empty import UserProfilePhotoEmpty
from .user_profile_photo import UserProfilePhoto
from .user_status_empty import UserStatusEmpty
from .user_status_online import UserStatusOnline
from .user_status_offline import UserStatusOffline
from .user_status_recently import UserStatusRecently
from .user_status_last_week import UserStatusLastWeek
from .user_status_last_month import UserStatusLastMonth
from .chat_empty import ChatEmpty
from .chat import Chat
from .chat_forbidden import ChatForbidden
from .channel import Channel
from .channel_forbidden import ChannelForbidden
from .chat_full import ChatFull
from .channel_full import ChannelFull
from .chat_participant import ChatParticipant
from .chat_participant_creator import ChatParticipantCreator
from .chat_participant_admin import ChatParticipantAdmin
from .chat_participants_forbidden import ChatParticipantsForbidden
from .chat_participants import ChatParticipants
from .chat_photo_empty import ChatPhotoEmpty
from .chat_photo import ChatPhoto
from .message_empty import MessageEmpty
from .message import Message
from .message_service import MessageService
from .message_media_empty import MessageMediaEmpty
from .message_media_photo import MessageMediaPhoto
from .message_media_geo import MessageMediaGeo
from .message_media_contact import MessageMediaContact
from .message_media_unsupported import MessageMediaUnsupported
from .message_media_document import MessageMediaDocument
from .message_media_web_page import MessageMediaWebPage
from .message_media_venue import MessageMediaVenue
from .message_media_game import MessageMediaGame
from .message_media_invoice import MessageMediaInvoice
from .message_action_empty import MessageActionEmpty
from .message_action_chat_create import MessageActionChatCreate
from .message_action_chat_edit_title import MessageActionChatEditTitle
from .message_action_chat_edit_photo import MessageActionChatEditPhoto
from .message_action_chat_delete_photo import MessageActionChatDeletePhoto
from .message_action_chat_add_user import MessageActionChatAddUser
from .message_action_chat_delete_user import MessageActionChatDeleteUser
from .message_action_chat_joined_by_link import MessageActionChatJoinedByLink
from .message_action_channel_create import MessageActionChannelCreate
from .message_action_chat_migrate_to import MessageActionChatMigrateTo
from .message_action_channel_migrate_from import MessageActionChannelMigrateFrom
from .message_action_pin_message import MessageActionPinMessage
from .message_action_history_clear import MessageActionHistoryClear
from .message_action_game_score import MessageActionGameScore
from .message_action_payment_sent_me import MessageActionPaymentSentMe
from .message_action_payment_sent import MessageActionPaymentSent
from .message_action_phone_call import MessageActionPhoneCall
from .dialog import Dialog
from .photo_empty import PhotoEmpty
from .photo import Photo
from .photo_size_empty import PhotoSizeEmpty
from .photo_size import PhotoSize
from .photo_cached_size import PhotoCachedSize
from .geo_point_empty import GeoPointEmpty
from .geo_point import GeoPoint
from .input_notify_peer import InputNotifyPeer
from .input_notify_users import InputNotifyUsers
from .input_notify_chats import InputNotifyChats
from .input_notify_all import InputNotifyAll
from .input_peer_notify_events_empty import InputPeerNotifyEventsEmpty
from .input_peer_notify_events_all import InputPeerNotifyEventsAll
from .input_peer_notify_settings import InputPeerNotifySettings
from .peer_notify_events_empty import PeerNotifyEventsEmpty
from .peer_notify_events_all import PeerNotifyEventsAll
from .peer_notify_settings_empty import PeerNotifySettingsEmpty
from .peer_notify_settings import PeerNotifySettings
from .peer_settings import PeerSettings
from .wall_paper import WallPaper
from .wall_paper_solid import WallPaperSolid
from .input_report_reason_spam import InputReportReasonSpam
from .input_report_reason_violence import InputReportReasonViolence
from .input_report_reason_pornography import InputReportReasonPornography
from .input_report_reason_other import InputReportReasonOther
from .user_full import UserFull
from .contact import Contact
from .imported_contact import ImportedContact
from .contact_blocked import ContactBlocked
from .contact_status import ContactStatus
from .input_messages_filter_empty import InputMessagesFilterEmpty
from .input_messages_filter_photos import InputMessagesFilterPhotos
from .input_messages_filter_video import InputMessagesFilterVideo
from .input_messages_filter_photo_video import InputMessagesFilterPhotoVideo
from .input_messages_filter_photo_video_documents import InputMessagesFilterPhotoVideoDocuments
from .input_messages_filter_document import InputMessagesFilterDocument
from .input_messages_filter_url import InputMessagesFilterUrl
from .input_messages_filter_gif import InputMessagesFilterGif
from .input_messages_filter_voice import InputMessagesFilterVoice
from .input_messages_filter_music import InputMessagesFilterMusic
from .input_messages_filter_chat_photos import InputMessagesFilterChatPhotos
from .input_messages_filter_phone_calls import InputMessagesFilterPhoneCalls
from .input_messages_filter_round_voice import InputMessagesFilterRoundVoice
from .input_messages_filter_round_video import InputMessagesFilterRoundVideo
from .update_new_message import UpdateNewMessage
from .update_message_id import UpdateMessageID
from .update_delete_messages import UpdateDeleteMessages
from .update_user_typing import UpdateUserTyping
from .update_chat_user_typing import UpdateChatUserTyping
from .update_chat_participants import UpdateChatParticipants
from .update_user_status import UpdateUserStatus
from .update_user_name import UpdateUserName
from .update_user_photo import UpdateUserPhoto
from .update_contact_registered import UpdateContactRegistered
from .update_contact_link import UpdateContactLink
from .update_new_encrypted_message import UpdateNewEncryptedMessage
from .update_encrypted_chat_typing import UpdateEncryptedChatTyping
from .update_encryption import UpdateEncryption
from .update_encrypted_messages_read import UpdateEncryptedMessagesRead
from .update_chat_participant_add import UpdateChatParticipantAdd
from .update_chat_participant_delete import UpdateChatParticipantDelete
from .update_dc_options import UpdateDcOptions
from .update_user_blocked import UpdateUserBlocked
from .update_notify_settings import UpdateNotifySettings
from .update_service_notification import UpdateServiceNotification
from .update_privacy import UpdatePrivacy
from .update_user_phone import UpdateUserPhone
from .update_read_history_inbox import UpdateReadHistoryInbox
from .update_read_history_outbox import UpdateReadHistoryOutbox
from .update_web_page import UpdateWebPage
from .update_read_messages_contents import UpdateReadMessagesContents
from .update_channel_too_long import UpdateChannelTooLong
from .update_channel import UpdateChannel
from .update_new_channel_message import UpdateNewChannelMessage
from .update_read_channel_inbox import UpdateReadChannelInbox
from .update_delete_channel_messages import UpdateDeleteChannelMessages
from .update_channel_message_views import UpdateChannelMessageViews
from .update_chat_admins import UpdateChatAdmins
from .update_chat_participant_admin import UpdateChatParticipantAdmin
from .update_new_sticker_set import UpdateNewStickerSet
from .update_sticker_sets_order import UpdateStickerSetsOrder
from .update_sticker_sets import UpdateStickerSets
from .update_saved_gifs import UpdateSavedGifs
from .update_bot_inline_query import UpdateBotInlineQuery
from .update_bot_inline_send import UpdateBotInlineSend
from .update_edit_channel_message import UpdateEditChannelMessage
from .update_channel_pinned_message import UpdateChannelPinnedMessage
from .update_bot_callback_query import UpdateBotCallbackQuery
from .update_edit_message import UpdateEditMessage
from .update_inline_bot_callback_query import UpdateInlineBotCallbackQuery
from .update_read_channel_outbox import UpdateReadChannelOutbox
from .update_draft_message import UpdateDraftMessage
from .update_read_featured_stickers import UpdateReadFeaturedStickers
from .update_recent_stickers import UpdateRecentStickers
from .update_config import UpdateConfig
from .update_pts_changed import UpdatePtsChanged
from .update_channel_web_page import UpdateChannelWebPage
from .update_dialog_pinned import UpdateDialogPinned
from .update_pinned_dialogs import UpdatePinnedDialogs
from .update_bot_webhook_json import UpdateBotWebhookJSON
from .update_bot_webhook_json_query import UpdateBotWebhookJSONQuery
from .update_bot_shipping_query import UpdateBotShippingQuery
from .update_bot_precheckout_query import UpdateBotPrecheckoutQuery
from .update_phone_call import UpdatePhoneCall
from .updates_too_long import UpdatesTooLong
from .update_short_message import UpdateShortMessage
from .update_short_chat_message import UpdateShortChatMessage
from .update_short import UpdateShort
from .updates_combined import UpdatesCombined
from .updates_tg import UpdatesTg
from .update_short_sent_message import UpdateShortSentMessage
from .dc_option import DcOption
from .config import Config
from .nearest_dc import NearestDc
from .encrypted_chat_empty import EncryptedChatEmpty
from .encrypted_chat_waiting import EncryptedChatWaiting
from .encrypted_chat_requested import EncryptedChatRequested
from .encrypted_chat import EncryptedChat
from .encrypted_chat_discarded import EncryptedChatDiscarded
from .input_encrypted_chat import InputEncryptedChat
from .encrypted_file_empty import EncryptedFileEmpty
from .encrypted_file import EncryptedFile
from .input_encrypted_file_empty import InputEncryptedFileEmpty
from .input_encrypted_file_uploaded import InputEncryptedFileUploaded
from .input_encrypted_file import InputEncryptedFile
from .input_encrypted_file_big_uploaded import InputEncryptedFileBigUploaded
from .encrypted_message import EncryptedMessage
from .encrypted_message_service import EncryptedMessageService
from .input_document_empty import InputDocumentEmpty
from .input_document import InputDocument
from .document_empty import DocumentEmpty
from .document import Document
from .notify_peer import NotifyPeer
from .notify_users import NotifyUsers
from .notify_chats import NotifyChats
from .notify_all import NotifyAll
from .send_message_typing_action import SendMessageTypingAction
from .send_message_cancel_action import SendMessageCancelAction
from .send_message_record_video_action import SendMessageRecordVideoAction
from .send_message_upload_video_action import SendMessageUploadVideoAction
from .send_message_record_audio_action import SendMessageRecordAudioAction
from .send_message_upload_audio_action import SendMessageUploadAudioAction
from .send_message_upload_photo_action import SendMessageUploadPhotoAction
from .send_message_upload_document_action import SendMessageUploadDocumentAction
from .send_message_geo_location_action import SendMessageGeoLocationAction
from .send_message_choose_contact_action import SendMessageChooseContactAction
from .send_message_game_play_action import SendMessageGamePlayAction
from .send_message_record_round_action import SendMessageRecordRoundAction
from .send_message_upload_round_action import SendMessageUploadRoundAction
from .input_privacy_key_status_timestamp import InputPrivacyKeyStatusTimestamp
from .input_privacy_key_chat_invite import InputPrivacyKeyChatInvite
from .input_privacy_key_phone_call import InputPrivacyKeyPhoneCall
from .privacy_key_status_timestamp import PrivacyKeyStatusTimestamp
from .privacy_key_chat_invite import PrivacyKeyChatInvite
from .privacy_key_phone_call import PrivacyKeyPhoneCall
from .input_privacy_value_allow_contacts import InputPrivacyValueAllowContacts
from .input_privacy_value_allow_all import InputPrivacyValueAllowAll
from .input_privacy_value_allow_users import InputPrivacyValueAllowUsers
from .input_privacy_value_disallow_contacts import InputPrivacyValueDisallowContacts
from .input_privacy_value_disallow_all import InputPrivacyValueDisallowAll
from .input_privacy_value_disallow_users import InputPrivacyValueDisallowUsers
from .privacy_value_allow_contacts import PrivacyValueAllowContacts
from .privacy_value_allow_all import PrivacyValueAllowAll
from .privacy_value_allow_users import PrivacyValueAllowUsers
from .privacy_value_disallow_contacts import PrivacyValueDisallowContacts
from .privacy_value_disallow_all import PrivacyValueDisallowAll
from .privacy_value_disallow_users import PrivacyValueDisallowUsers
from .account_days_ttl import AccountDaysTTL
from .document_attribute_image_size import DocumentAttributeImageSize
from .document_attribute_animated import DocumentAttributeAnimated
from .document_attribute_sticker import DocumentAttributeSticker
from .document_attribute_video import DocumentAttributeVideo
from .document_attribute_audio import DocumentAttributeAudio
from .document_attribute_filename import DocumentAttributeFilename
from .document_attribute_has_stickers import DocumentAttributeHasStickers
from .sticker_pack import StickerPack
from .disabled_feature import DisabledFeature
from .contact_link_unknown import ContactLinkUnknown
from .contact_link_none import ContactLinkNone
from .contact_link_has_phone import ContactLinkHasPhone
from .contact_link_contact import ContactLinkContact
from .web_page_empty import WebPageEmpty
from .web_page_pending import WebPagePending
from .web_page import WebPage
from .web_page_not_modified import WebPageNotModified
from .authorization import Authorization
from .received_notify_message import ReceivedNotifyMessage
from .chat_invite_empty import ChatInviteEmpty
from .chat_invite_exported import ChatInviteExported
from .chat_invite_already import ChatInviteAlready
from .chat_invite import ChatInvite
from .input_sticker_set_empty import InputStickerSetEmpty
from .input_sticker_set_id import InputStickerSetID
from .input_sticker_set_short_name import InputStickerSetShortName
from .sticker_set import StickerSet
from .bot_command import BotCommand
from .bot_info import BotInfo
from .keyboard_button import KeyboardButton
from .keyboard_button_url import KeyboardButtonUrl
from .keyboard_button_callback import KeyboardButtonCallback
from .keyboard_button_request_phone import KeyboardButtonRequestPhone
from .keyboard_button_request_geo_location import KeyboardButtonRequestGeoLocation
from .keyboard_button_switch_inline import KeyboardButtonSwitchInline
from .keyboard_button_game import KeyboardButtonGame
from .keyboard_button_buy import KeyboardButtonBuy
from .keyboard_button_row import KeyboardButtonRow
from .reply_keyboard_hide import ReplyKeyboardHide
from .reply_keyboard_force_reply import ReplyKeyboardForceReply
from .reply_keyboard_markup import ReplyKeyboardMarkup
from .reply_inline_markup import ReplyInlineMarkup
from .message_entity_unknown import MessageEntityUnknown
from .message_entity_mention import MessageEntityMention
from .message_entity_hashtag import MessageEntityHashtag
from .message_entity_bot_command import MessageEntityBotCommand
from .message_entity_url import MessageEntityUrl
from .message_entity_email import MessageEntityEmail
from .message_entity_bold import MessageEntityBold
from .message_entity_italic import MessageEntityItalic
from .message_entity_code import MessageEntityCode
from .message_entity_pre import MessageEntityPre
from .message_entity_text_url import MessageEntityTextUrl
from .message_entity_mention_name import MessageEntityMentionName
from .input_message_entity_mention_name import InputMessageEntityMentionName
from .input_channel_empty import InputChannelEmpty
from .input_channel import InputChannel
from .message_range import MessageRange
from .channel_messages_filter_empty import ChannelMessagesFilterEmpty
from .channel_messages_filter import ChannelMessagesFilter
from .channel_participant import ChannelParticipant
from .channel_participant_self import ChannelParticipantSelf
from .channel_participant_moderator import ChannelParticipantModerator
from .channel_participant_editor import ChannelParticipantEditor
from .channel_participant_kicked import ChannelParticipantKicked
from .channel_participant_creator import ChannelParticipantCreator
from .channel_participants_recent import ChannelParticipantsRecent
from .channel_participants_admins import ChannelParticipantsAdmins
from .channel_participants_kicked import ChannelParticipantsKicked
from .channel_participants_bots import ChannelParticipantsBots
from .channel_role_empty import ChannelRoleEmpty
from .channel_role_moderator import ChannelRoleModerator
from .channel_role_editor import ChannelRoleEditor
from .found_gif import FoundGif
from .found_gif_cached import FoundGifCached
from .input_bot_inline_message_media_auto import InputBotInlineMessageMediaAuto
from .input_bot_inline_message_text import InputBotInlineMessageText
from .input_bot_inline_message_media_geo import InputBotInlineMessageMediaGeo
from .input_bot_inline_message_media_venue import InputBotInlineMessageMediaVenue
from .input_bot_inline_message_media_contact import InputBotInlineMessageMediaContact
from .input_bot_inline_message_game import InputBotInlineMessageGame
from .input_bot_inline_result import InputBotInlineResult
from .input_bot_inline_result_photo import InputBotInlineResultPhoto
from .input_bot_inline_result_document import InputBotInlineResultDocument
from .input_bot_inline_result_game import InputBotInlineResultGame
from .bot_inline_message_media_auto import BotInlineMessageMediaAuto
from .bot_inline_message_text import BotInlineMessageText
from .bot_inline_message_media_geo import BotInlineMessageMediaGeo
from .bot_inline_message_media_venue import BotInlineMessageMediaVenue
from .bot_inline_message_media_contact import BotInlineMessageMediaContact
from .bot_inline_result import BotInlineResult
from .bot_inline_media_result import BotInlineMediaResult
from .exported_message_link import ExportedMessageLink
from .message_fwd_header import MessageFwdHeader
from .input_bot_inline_message_id import InputBotInlineMessageID
from .inline_bot_switch_pm import InlineBotSwitchPM
from .top_peer import TopPeer
from .top_peer_category_bots_pm import TopPeerCategoryBotsPM
from .top_peer_category_bots_inline import TopPeerCategoryBotsInline
from .top_peer_category_correspondents import TopPeerCategoryCorrespondents
from .top_peer_category_groups import TopPeerCategoryGroups
from .top_peer_category_channels import TopPeerCategoryChannels
from .top_peer_category_peers import TopPeerCategoryPeers
from .draft_message_empty import DraftMessageEmpty
from .draft_message import DraftMessage
from .sticker_set_covered import StickerSetCovered
from .sticker_set_multi_covered import StickerSetMultiCovered
from .mask_coords import MaskCoords
from .input_stickered_media_photo import InputStickeredMediaPhoto
from .input_stickered_media_document import InputStickeredMediaDocument
from .game import Game
from .input_game_id import InputGameID
from .input_game_short_name import InputGameShortName
from .high_score import HighScore
from .text_empty import TextEmpty
from .text_plain import TextPlain
from .text_bold import TextBold
from .text_italic import TextItalic
from .text_underline import TextUnderline
from .text_strike import TextStrike
from .text_fixed import TextFixed
from .text_url import TextUrl
from .text_email import TextEmail
from .text_concat import TextConcat
from .page_block_unsupported import PageBlockUnsupported
from .page_block_title import PageBlockTitle
from .page_block_subtitle import PageBlockSubtitle
from .page_block_author_date import PageBlockAuthorDate
from .page_block_header import PageBlockHeader
from .page_block_subheader import PageBlockSubheader
from .page_block_paragraph import PageBlockParagraph
from .page_block_preformatted import PageBlockPreformatted
from .page_block_footer import PageBlockFooter
from .page_block_divider import PageBlockDivider
from .page_block_anchor import PageBlockAnchor
from .page_block_list import PageBlockList
from .page_block_blockquote import PageBlockBlockquote
from .page_block_pullquote import PageBlockPullquote
from .page_block_photo import PageBlockPhoto
from .page_block_video import PageBlockVideo
from .page_block_cover import PageBlockCover
from .page_block_embed import PageBlockEmbed
from .page_block_embed_post import PageBlockEmbedPost
from .page_block_collage import PageBlockCollage
from .page_block_slideshow import PageBlockSlideshow
from .page_block_channel import PageBlockChannel
from .page_part import PagePart
from .page_full import PageFull
from .phone_call_discard_reason_missed import PhoneCallDiscardReasonMissed
from .phone_call_discard_reason_disconnect import PhoneCallDiscardReasonDisconnect
from .phone_call_discard_reason_hangup import PhoneCallDiscardReasonHangup
from .phone_call_discard_reason_busy import PhoneCallDiscardReasonBusy
from .data_json import DataJSON
from .labeled_price import LabeledPrice
from .invoice import Invoice
from .payment_charge import PaymentCharge
from .post_address import PostAddress
from .payment_requested_info import PaymentRequestedInfo
from .payment_saved_credentials_card import PaymentSavedCredentialsCard
from .web_document import WebDocument
from .input_web_document import InputWebDocument
from .input_web_file_location import InputWebFileLocation
from .input_payment_credentials_saved import InputPaymentCredentialsSaved
from .input_payment_credentials import InputPaymentCredentials
from .shipping_option import ShippingOption
from .input_phone_call import InputPhoneCall
from .phone_call_empty import PhoneCallEmpty
from .phone_call_waiting import PhoneCallWaiting
from .phone_call_requested import PhoneCallRequested
from .phone_call_accepted import PhoneCallAccepted
from .phone_call import PhoneCall
from .phone_call_discarded import PhoneCallDiscarded
from .phone_connection import PhoneConnection
from .phone_call_protocol import PhoneCallProtocol
from .cdn_public_key import CdnPublicKey
from .cdn_config import CdnConfig
from . import account, contacts, auth, messages, help, channels, storage, phone, photos, updates, upload, payments



from ....tl.mtproto_request import MTProtoRequest


class ExportedAuthorization(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    auth.exportedAuthorization#df969c2d id:int bytes:bytes = auth.ExportedAuthorization"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xdf969c2d

    def __init__(self, id, bytes):
        """
        :param id: Telegram type: «int».
        :param bytes: Telegram type: «bytes».

        Constructor for auth.ExportedAuthorization: Instance of ExportedAuthorization.
        """
        super().__init__()

        self.id = id
        self.bytes = bytes

    def on_send(self, writer):
        writer.write_int(ExportedAuthorization.constructor_id, signed=False)
        writer.write_int(self.id)
        writer.tgwrite_bytes(self.bytes)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return ExportedAuthorization(None, None)

    def on_response(self, reader):
        self.id = reader.read_int()
        self.bytes = reader.tgread_bytes()

    def __repr__(self):
        return 'auth.exportedAuthorization#df969c2d id:int bytes:bytes = auth.ExportedAuthorization'

    def __str__(self):
        return '(auth.exportedAuthorization (ID: 0xdf969c2d) = (id={}, bytes={}))'.format(str(self.id), str(self.bytes))



from ....tl.mtproto_request import MTProtoRequest


class StickerSetInstallResultArchive(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.stickerSetInstallResultArchive#35e410a8 sets:Vector<StickerSetCovered> = messages.StickerSetInstallResult"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x35e410a8

    def __init__(self, sets):
        """
        :param sets: Telegram type: «StickerSetCovered». Must be a list.

        Constructor for messages.StickerSetInstallResult: Instance of either StickerSetInstallResultSuccess, StickerSetInstallResultArchive.
        """
        super().__init__()

        self.sets = sets

    def on_send(self, writer):
        writer.write_int(StickerSetInstallResultArchive.constructor_id, signed=False)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.sets))
        for sets_item in self.sets:
            sets_item.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return StickerSetInstallResultArchive(None)

    def on_response(self, reader):
        reader.read_int()  # Vector's constructor ID
        self.sets = []  # Initialize an empty list
        sets_len = reader.read_int()
        for _ in range(sets_len):
            sets_item = reader.tgread_object()
            self.sets.append(sets_item)

    def __repr__(self):
        return 'messages.stickerSetInstallResultArchive#35e410a8 sets:Vector<StickerSetCovered> = messages.StickerSetInstallResult'

    def __str__(self):
        return '(messages.stickerSetInstallResultArchive (ID: 0x35e410a8) = (sets={}))'.format(None if not self.sets else [str(_) for _ in self.sets])



from ...tl.mtproto_request import MTProtoRequest


class PhoneCallWaiting(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    phoneCallWaiting#1b8f4ad1 flags:# id:long access_hash:long date:date admin_id:int participant_id:int protocol:PhoneCallProtocol receive_date:flags.0?date = PhoneCall"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x1b8f4ad1

    def __init__(self, id, access_hash, date, admin_id, participant_id, protocol, receive_date=None):
        """
        :param id: Telegram type: «long».
        :param access_hash: Telegram type: «long».
        :param date: Telegram type: «date».
        :param admin_id: Telegram type: «int».
        :param participant_id: Telegram type: «int».
        :param protocol: Telegram type: «PhoneCallProtocol».
        :param receive_date: Telegram type: «date».

        Constructor for PhoneCall: Instance of either PhoneCallEmpty, PhoneCallWaiting, PhoneCallRequested, PhoneCallAccepted, PhoneCall, PhoneCallDiscarded.
        """
        super().__init__()

        self.id = id
        self.access_hash = access_hash
        self.date = date
        self.admin_id = admin_id
        self.participant_id = participant_id
        self.protocol = protocol
        self.receive_date = receive_date

    def on_send(self, writer):
        writer.write_int(PhoneCallWaiting.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.receive_date else 0
        writer.write_int(flags)

        writer.write_long(self.id)
        writer.write_long(self.access_hash)
        writer.tgwrite_date(self.date)
        writer.write_int(self.admin_id)
        writer.write_int(self.participant_id)
        self.protocol.on_send(writer)
        if self.receive_date:
            writer.tgwrite_date(self.receive_date)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return PhoneCallWaiting(None, None, None, None, None, None, None)

    def on_response(self, reader):
        flags = reader.read_int()

        self.id = reader.read_long()
        self.access_hash = reader.read_long()
        self.date = reader.tgread_date()
        self.admin_id = reader.read_int()
        self.participant_id = reader.read_int()
        self.protocol = reader.tgread_object()
        if (flags & (1 << 0)) != 0:
            self.receive_date = reader.tgread_date()

    def __repr__(self):
        return 'phoneCallWaiting#1b8f4ad1 flags:# id:long access_hash:long date:date admin_id:int participant_id:int protocol:PhoneCallProtocol receive_date:flags.0?date = PhoneCall'

    def __str__(self):
        return '(phoneCallWaiting (ID: 0x1b8f4ad1) = (id={}, access_hash={}, date={}, admin_id={}, participant_id={}, protocol={}, receive_date={}))'.format(str(self.id), str(self.access_hash), str(self.date), str(self.admin_id), str(self.participant_id), str(self.protocol), str(self.receive_date))



from ....tl.mtproto_request import MTProtoRequest


class SavedGifs(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.savedGifs#2e0709a5 hash:int gifs:Vector<Document> = messages.SavedGifs"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x2e0709a5

    def __init__(self, hash, gifs):
        """
        :param hash: Telegram type: «int».
        :param gifs: Telegram type: «Document». Must be a list.

        Constructor for messages.SavedGifs: Instance of either SavedGifsNotModified, SavedGifs.
        """
        super().__init__()

        self.hash = hash
        self.gifs = gifs

    def on_send(self, writer):
        writer.write_int(SavedGifs.constructor_id, signed=False)
        writer.write_int(self.hash)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.gifs))
        for gifs_item in self.gifs:
            gifs_item.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return SavedGifs(None, None)

    def on_response(self, reader):
        self.hash = reader.read_int()
        reader.read_int()  # Vector's constructor ID
        self.gifs = []  # Initialize an empty list
        gifs_len = reader.read_int()
        for _ in range(gifs_len):
            gifs_item = reader.tgread_object()
            self.gifs.append(gifs_item)

    def __repr__(self):
        return 'messages.savedGifs#2e0709a5 hash:int gifs:Vector<Document> = messages.SavedGifs'

    def __str__(self):
        return '(messages.savedGifs (ID: 0x2e0709a5) = (hash={}, gifs={}))'.format(str(self.hash), None if not self.gifs else [str(_) for _ in self.gifs])



from ....tl.mtproto_request import MTProtoRequest


class ChannelDifference(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updates.channelDifference#2064674e flags:# final:flags.0?true pts:int timeout:flags.1?int new_messages:Vector<Message> other_updates:Vector<Update> chats:Vector<Chat> users:Vector<User> = updates.ChannelDifference"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x2064674e

    def __init__(self, pts, new_messages, other_updates, chats, users, final=None, timeout=None):
        """
        :param final: Telegram type: «true».
        :param pts: Telegram type: «int».
        :param timeout: Telegram type: «int».
        :param new_messages: Telegram type: «Message». Must be a list.
        :param other_updates: Telegram type: «Update». Must be a list.
        :param chats: Telegram type: «Chat». Must be a list.
        :param users: Telegram type: «User». Must be a list.

        Constructor for updates.ChannelDifference: Instance of either ChannelDifferenceEmpty, ChannelDifferenceTooLong, ChannelDifference.
        """
        super().__init__()

        self.final = final
        self.pts = pts
        self.timeout = timeout
        self.new_messages = new_messages
        self.other_updates = other_updates
        self.chats = chats
        self.users = users

    def on_send(self, writer):
        writer.write_int(ChannelDifference.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.final else 0
        flags |= (1 << 1) if self.timeout else 0
        writer.write_int(flags)

        writer.write_int(self.pts)
        if self.timeout:
            writer.write_int(self.timeout)

        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.new_messages))
        for new_messages_item in self.new_messages:
            new_messages_item.on_send(writer)

        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.other_updates))
        for other_updates_item in self.other_updates:
            other_updates_item.on_send(writer)

        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.chats))
        for chats_item in self.chats:
            chats_item.on_send(writer)

        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.users))
        for users_item in self.users:
            users_item.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return ChannelDifference(None, None, None, None, None, None, None)

    def on_response(self, reader):
        flags = reader.read_int()

        if (flags & (1 << 0)) != 0:
            self.final = True  # Arbitrary not-None value, no need to read since it is a flag

        self.pts = reader.read_int()
        if (flags & (1 << 1)) != 0:
            self.timeout = reader.read_int()

        reader.read_int()  # Vector's constructor ID
        self.new_messages = []  # Initialize an empty list
        new_messages_len = reader.read_int()
        for _ in range(new_messages_len):
            new_messages_item = reader.tgread_object()
            self.new_messages.append(new_messages_item)

        reader.read_int()  # Vector's constructor ID
        self.other_updates = []  # Initialize an empty list
        other_updates_len = reader.read_int()
        for _ in range(other_updates_len):
            other_updates_item = reader.tgread_object()
            self.other_updates.append(other_updates_item)

        reader.read_int()  # Vector's constructor ID
        self.chats = []  # Initialize an empty list
        chats_len = reader.read_int()
        for _ in range(chats_len):
            chats_item = reader.tgread_object()
            self.chats.append(chats_item)

        reader.read_int()  # Vector's constructor ID
        self.users = []  # Initialize an empty list
        users_len = reader.read_int()
        for _ in range(users_len):
            users_item = reader.tgread_object()
            self.users.append(users_item)

    def __repr__(self):
        return 'updates.channelDifference#2064674e flags:# final:flags.0?true pts:int timeout:flags.1?int new_messages:Vector<Message> other_updates:Vector<Update> chats:Vector<Chat> users:Vector<User> = updates.ChannelDifference'

    def __str__(self):
        return '(updates.channelDifference (ID: 0x2064674e) = (final={}, pts={}, timeout={}, new_messages={}, other_updates={}, chats={}, users={}))'.format(str(self.final), str(self.pts), str(self.timeout), None if not self.new_messages else [str(_) for _ in self.new_messages], None if not self.other_updates else [str(_) for _ in self.other_updates], None if not self.chats else [str(_) for _ in self.chats], None if not self.users else [str(_) for _ in self.users])



from ....tl.mtproto_request import MTProtoRequest


class FoundGifs(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.foundGifs#450a1c0a next_offset:int results:Vector<FoundGif> = messages.FoundGifs"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x450a1c0a

    def __init__(self, next_offset, results):
        """
        :param next_offset: Telegram type: «int».
        :param results: Telegram type: «FoundGif». Must be a list.

        Constructor for messages.FoundGifs: Instance of FoundGifs.
        """
        super().__init__()

        self.next_offset = next_offset
        self.results = results

    def on_send(self, writer):
        writer.write_int(FoundGifs.constructor_id, signed=False)
        writer.write_int(self.next_offset)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.results))
        for results_item in self.results:
            results_item.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return FoundGifs(None, None)

    def on_response(self, reader):
        self.next_offset = reader.read_int()
        reader.read_int()  # Vector's constructor ID
        self.results = []  # Initialize an empty list
        results_len = reader.read_int()
        for _ in range(results_len):
            results_item = reader.tgread_object()
            self.results.append(results_item)

    def __repr__(self):
        return 'messages.foundGifs#450a1c0a next_offset:int results:Vector<FoundGif> = messages.FoundGifs'

    def __str__(self):
        return '(messages.foundGifs (ID: 0x450a1c0a) = (next_offset={}, results={}))'.format(str(self.next_offset), None if not self.results else [str(_) for _ in self.results])



from .get_statuses import GetStatusesRequest
from .get_contacts import GetContactsRequest
from .import_contacts import ImportContactsRequest
from .delete_contact import DeleteContactRequest
from .delete_contacts import DeleteContactsRequest
from .block import BlockRequest
from .unblock import UnblockRequest
from .get_blocked import GetBlockedRequest
from .export_card import ExportCardRequest
from .import_card import ImportCardRequest
from .search import SearchRequest
from .resolve_username import ResolveUsernameRequest
from .get_top_peers import GetTopPeersRequest
from .reset_top_peer_rating import ResetTopPeerRatingRequest



from ...tl.mtproto_request import MTProtoRequest


class UpdateBotInlineSend(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateBotInlineSend#0e48f964 flags:# user_id:int query:string geo:flags.0?GeoPoint id:string msg_id:flags.1?InputBotInlineMessageID = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xe48f964

    def __init__(self, user_id, query, id, geo=None, msg_id=None):
        """
        :param user_id: Telegram type: «int».
        :param query: Telegram type: «string».
        :param geo: Telegram type: «GeoPoint».
        :param id: Telegram type: «string».
        :param msg_id: Telegram type: «InputBotInlineMessageID».

        Constructor for Update: Instance of either UpdateNewMessage, UpdateMessageID, UpdateDeleteMessages, UpdateUserTyping, UpdateChatUserTyping, UpdateChatParticipants, UpdateUserStatus, UpdateUserName, UpdateUserPhoto, UpdateContactRegistered, UpdateContactLink, UpdateNewEncryptedMessage, UpdateEncryptedChatTyping, UpdateEncryption, UpdateEncryptedMessagesRead, UpdateChatParticipantAdd, UpdateChatParticipantDelete, UpdateDcOptions, UpdateUserBlocked, UpdateNotifySettings, UpdateServiceNotification, UpdatePrivacy, UpdateUserPhone, UpdateReadHistoryInbox, UpdateReadHistoryOutbox, UpdateWebPage, UpdateReadMessagesContents, UpdateChannelTooLong, UpdateChannel, UpdateNewChannelMessage, UpdateReadChannelInbox, UpdateDeleteChannelMessages, UpdateChannelMessageViews, UpdateChatAdmins, UpdateChatParticipantAdmin, UpdateNewStickerSet, UpdateStickerSetsOrder, UpdateStickerSets, UpdateSavedGifs, UpdateBotInlineQuery, UpdateBotInlineSend, UpdateEditChannelMessage, UpdateChannelPinnedMessage, UpdateBotCallbackQuery, UpdateEditMessage, UpdateInlineBotCallbackQuery, UpdateReadChannelOutbox, UpdateDraftMessage, UpdateReadFeaturedStickers, UpdateRecentStickers, UpdateConfig, UpdatePtsChanged, UpdateChannelWebPage, UpdateDialogPinned, UpdatePinnedDialogs, UpdateBotWebhookJSON, UpdateBotWebhookJSONQuery, UpdateBotShippingQuery, UpdateBotPrecheckoutQuery, UpdatePhoneCall.
        """
        super().__init__()

        self.user_id = user_id
        self.query = query
        self.geo = geo
        self.id = id
        self.msg_id = msg_id

    def on_send(self, writer):
        writer.write_int(UpdateBotInlineSend.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.geo else 0
        flags |= (1 << 1) if self.msg_id else 0
        writer.write_int(flags)

        writer.write_int(self.user_id)
        writer.tgwrite_string(self.query)
        if self.geo:
            self.geo.on_send(writer)

        writer.tgwrite_string(self.id)
        if self.msg_id:
            self.msg_id.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateBotInlineSend(None, None, None, None, None)

    def on_response(self, reader):
        flags = reader.read_int()

        self.user_id = reader.read_int()
        self.query = reader.tgread_string()
        if (flags & (1 << 0)) != 0:
            self.geo = reader.tgread_object()

        self.id = reader.tgread_string()
        if (flags & (1 << 1)) != 0:
            self.msg_id = reader.tgread_object()

    def __repr__(self):
        return 'updateBotInlineSend#0e48f964 flags:# user_id:int query:string geo:flags.0?GeoPoint id:string msg_id:flags.1?InputBotInlineMessageID = Update'

    def __str__(self):
        return '(updateBotInlineSend (ID: 0xe48f964) = (user_id={}, query={}, geo={}, id={}, msg_id={}))'.format(str(self.user_id), str(self.query), str(self.geo), str(self.id), str(self.msg_id))



from ...tl.mtproto_request import MTProtoRequest


class BotInlineMessageMediaContact(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    botInlineMessageMediaContact#35edb4d4 flags:# phone_number:string first_name:string last_name:string reply_markup:flags.2?ReplyMarkup = BotInlineMessage"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x35edb4d4

    def __init__(self, phone_number, first_name, last_name, reply_markup=None):
        """
        :param phone_number: Telegram type: «string».
        :param first_name: Telegram type: «string».
        :param last_name: Telegram type: «string».
        :param reply_markup: Telegram type: «ReplyMarkup».

        Constructor for BotInlineMessage: Instance of either BotInlineMessageMediaAuto, BotInlineMessageText, BotInlineMessageMediaGeo, BotInlineMessageMediaVenue, BotInlineMessageMediaContact.
        """
        super().__init__()

        self.phone_number = phone_number
        self.first_name = first_name
        self.last_name = last_name
        self.reply_markup = reply_markup

    def on_send(self, writer):
        writer.write_int(BotInlineMessageMediaContact.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 2) if self.reply_markup else 0
        writer.write_int(flags)

        writer.tgwrite_string(self.phone_number)
        writer.tgwrite_string(self.first_name)
        writer.tgwrite_string(self.last_name)
        if self.reply_markup:
            self.reply_markup.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return BotInlineMessageMediaContact(None, None, None, None)

    def on_response(self, reader):
        flags = reader.read_int()

        self.phone_number = reader.tgread_string()
        self.first_name = reader.tgread_string()
        self.last_name = reader.tgread_string()
        if (flags & (1 << 2)) != 0:
            self.reply_markup = reader.tgread_object()

    def __repr__(self):
        return 'botInlineMessageMediaContact#35edb4d4 flags:# phone_number:string first_name:string last_name:string reply_markup:flags.2?ReplyMarkup = BotInlineMessage'

    def __str__(self):
        return '(botInlineMessageMediaContact (ID: 0x35edb4d4) = (phone_number={}, first_name={}, last_name={}, reply_markup={}))'.format(str(self.phone_number), str(self.first_name), str(self.last_name), str(self.reply_markup))



from ...tl.mtproto_request import MTProtoRequest


class InputBotInlineResultGame(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    inputBotInlineResultGame#4fa417f2 id:string short_name:string send_message:InputBotInlineMessage = InputBotInlineResult"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x4fa417f2

    def __init__(self, id, short_name, send_message):
        """
        :param id: Telegram type: «string».
        :param short_name: Telegram type: «string».
        :param send_message: Telegram type: «InputBotInlineMessage».

        Constructor for InputBotInlineResult: Instance of either InputBotInlineResult, InputBotInlineResultPhoto, InputBotInlineResultDocument, InputBotInlineResultGame.
        """
        super().__init__()

        self.id = id
        self.short_name = short_name
        self.send_message = send_message

    def on_send(self, writer):
        writer.write_int(InputBotInlineResultGame.constructor_id, signed=False)
        writer.tgwrite_string(self.id)
        writer.tgwrite_string(self.short_name)
        self.send_message.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return InputBotInlineResultGame(None, None, None)

    def on_response(self, reader):
        self.id = reader.tgread_string()
        self.short_name = reader.tgread_string()
        self.send_message = reader.tgread_object()

    def __repr__(self):
        return 'inputBotInlineResultGame#4fa417f2 id:string short_name:string send_message:InputBotInlineMessage = InputBotInlineResult'

    def __str__(self):
        return '(inputBotInlineResultGame (ID: 0x4fa417f2) = (id={}, short_name={}, send_message={}))'.format(str(self.id), str(self.short_name), str(self.send_message))



from ....tl.mtproto_request import MTProtoRequest


class Support(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    help.support#17c6b5f6 phone_number:string user:User = help.Support"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x17c6b5f6

    def __init__(self, phone_number, user):
        """
        :param phone_number: Telegram type: «string».
        :param user: Telegram type: «User».

        Constructor for help.Support: Instance of Support.
        """
        super().__init__()

        self.phone_number = phone_number
        self.user = user

    def on_send(self, writer):
        writer.write_int(Support.constructor_id, signed=False)
        writer.tgwrite_string(self.phone_number)
        self.user.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return Support(None, None)

    def on_response(self, reader):
        self.phone_number = reader.tgread_string()
        self.user = reader.tgread_object()

    def __repr__(self):
        return 'help.support#17c6b5f6 phone_number:string user:User = help.Support'

    def __str__(self):
        return '(help.support (ID: 0x17c6b5f6) = (phone_number={}, user={}))'.format(str(self.phone_number), str(self.user))



from ...tl.mtproto_request import MTProtoRequest


class UpdatePinnedDialogs(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updatePinnedDialogs#d8caf68d flags:# order:flags.0?Vector<Peer> = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xd8caf68d

    def __init__(self, order=None):
        """
        :param order: Telegram type: «Peer». Must be a list.

        Constructor for Update: Instance of either UpdateNewMessage, UpdateMessageID, UpdateDeleteMessages, UpdateUserTyping, UpdateChatUserTyping, UpdateChatParticipants, UpdateUserStatus, UpdateUserName, UpdateUserPhoto, UpdateContactRegistered, UpdateContactLink, UpdateNewEncryptedMessage, UpdateEncryptedChatTyping, UpdateEncryption, UpdateEncryptedMessagesRead, UpdateChatParticipantAdd, UpdateChatParticipantDelete, UpdateDcOptions, UpdateUserBlocked, UpdateNotifySettings, UpdateServiceNotification, UpdatePrivacy, UpdateUserPhone, UpdateReadHistoryInbox, UpdateReadHistoryOutbox, UpdateWebPage, UpdateReadMessagesContents, UpdateChannelTooLong, UpdateChannel, UpdateNewChannelMessage, UpdateReadChannelInbox, UpdateDeleteChannelMessages, UpdateChannelMessageViews, UpdateChatAdmins, UpdateChatParticipantAdmin, UpdateNewStickerSet, UpdateStickerSetsOrder, UpdateStickerSets, UpdateSavedGifs, UpdateBotInlineQuery, UpdateBotInlineSend, UpdateEditChannelMessage, UpdateChannelPinnedMessage, UpdateBotCallbackQuery, UpdateEditMessage, UpdateInlineBotCallbackQuery, UpdateReadChannelOutbox, UpdateDraftMessage, UpdateReadFeaturedStickers, UpdateRecentStickers, UpdateConfig, UpdatePtsChanged, UpdateChannelWebPage, UpdateDialogPinned, UpdatePinnedDialogs, UpdateBotWebhookJSON, UpdateBotWebhookJSONQuery, UpdateBotShippingQuery, UpdateBotPrecheckoutQuery, UpdatePhoneCall.
        """
        super().__init__()

        self.order = order

    def on_send(self, writer):
        writer.write_int(UpdatePinnedDialogs.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.order else 0
        writer.write_int(flags)

        if self.order:
            writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
            writer.write_int(len(self.order))
            for order_item in self.order:
                if order_item:
                    order_item.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdatePinnedDialogs(None)

    def on_response(self, reader):
        flags = reader.read_int()

        if (flags & (1 << 0)) != 0:
            reader.read_int()  # Vector's constructor ID
            self.order = []  # Initialize an empty list
            order_len = reader.read_int()
            for _ in range(order_len):
                order_item = reader.tgread_object()
                self.order.append(order_item)

    def __repr__(self):
        return 'updatePinnedDialogs#d8caf68d flags:# order:flags.0?Vector<Peer> = Update'

    def __str__(self):
        return '(updatePinnedDialogs (ID: 0xd8caf68d) = (order={}))'.format(None if not self.order else [str(_) for _ in self.order])



from ...tl.mtproto_request import MTProtoRequest


class KeyboardButtonRequestPhone(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    keyboardButtonRequestPhone#b16a6c29 text:string = KeyboardButton"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xb16a6c29

    def __init__(self, text):
        """
        :param text: Telegram type: «string».

        Constructor for KeyboardButton: Instance of either KeyboardButton, KeyboardButtonUrl, KeyboardButtonCallback, KeyboardButtonRequestPhone, KeyboardButtonRequestGeoLocation, KeyboardButtonSwitchInline, KeyboardButtonGame, KeyboardButtonBuy.
        """
        super().__init__()

        self.text = text

    def on_send(self, writer):
        writer.write_int(KeyboardButtonRequestPhone.constructor_id, signed=False)
        writer.tgwrite_string(self.text)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return KeyboardButtonRequestPhone(None)

    def on_response(self, reader):
        self.text = reader.tgread_string()

    def __repr__(self):
        return 'keyboardButtonRequestPhone#b16a6c29 text:string = KeyboardButton'

    def __str__(self):
        return '(keyboardButtonRequestPhone (ID: 0xb16a6c29) = (text={}))'.format(str(self.text))



from ....tl.mtproto_request import MTProtoRequest


class GetUsersRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    users.getUsers#0d91a548 id:Vector<InputUser> = Vector<User>"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xd91a548

    def __init__(self, id):
        """
        :param id: Telegram type: «InputUser». Must be a list.

        :returns Vector<User>: This type has no constructors.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.id = id

    def on_send(self, writer):
        writer.write_int(GetUsersRequest.constructor_id, signed=False)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.id))
        for id_item in self.id:
            id_item.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return GetUsersRequest(None)

    def on_response(self, reader):
        self.result = reader.tgread_vector()

    def __repr__(self):
        return 'users.getUsers#0d91a548 id:Vector<InputUser> = Vector<User>'

    def __str__(self):
        return '(users.getUsers (ID: 0xd91a548) = (id={}))'.format(None if not self.id else [str(_) for _ in self.id])



from ...tl.mtproto_request import MTProtoRequest


class UserEmpty(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    userEmpty#200250ba id:int = User"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x200250ba

    def __init__(self, id):
        """
        :param id: Telegram type: «int».

        Constructor for User: Instance of either UserEmpty, User.
        """
        super().__init__()

        self.id = id

    def on_send(self, writer):
        writer.write_int(UserEmpty.constructor_id, signed=False)
        writer.write_int(self.id)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UserEmpty(None)

    def on_response(self, reader):
        self.id = reader.read_int()

    def __repr__(self):
        return 'userEmpty#200250ba id:int = User'

    def __str__(self):
        return '(userEmpty (ID: 0x200250ba) = (id={}))'.format(str(self.id))



from ....tl.mtproto_request import MTProtoRequest


class AcceptCallRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    phone.acceptCall#3bd2b4a0 peer:InputPhoneCall g_b:bytes protocol:PhoneCallProtocol = phone.PhoneCall"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x3bd2b4a0

    def __init__(self, peer, g_b, protocol):
        """
        :param peer: Telegram type: «InputPhoneCall».
        :param g_b: Telegram type: «bytes».
        :param protocol: Telegram type: «PhoneCallProtocol».

        :returns phone.PhoneCall: Instance of PhoneCall.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.peer = peer
        self.g_b = g_b
        self.protocol = protocol

    def on_send(self, writer):
        writer.write_int(AcceptCallRequest.constructor_id, signed=False)
        self.peer.on_send(writer)
        writer.tgwrite_bytes(self.g_b)
        self.protocol.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return AcceptCallRequest(None, None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'phone.acceptCall#3bd2b4a0 peer:InputPhoneCall g_b:bytes protocol:PhoneCallProtocol = phone.PhoneCall'

    def __str__(self):
        return '(phone.acceptCall (ID: 0x3bd2b4a0) = (peer={}, g_b={}, protocol={}))'.format(str(self.peer), str(self.g_b), str(self.protocol))



from ...tl.mtproto_request import MTProtoRequest


class InvokeWithLayerRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    invokeWithLayer#da9b0d0d {X:Type} layer:int query:!X = X"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xda9b0d0d

    def __init__(self, layer, query):
        """
        :param layer: Telegram type: «int».
        :param query: Telegram type: «X». This should be another MTProtoRequest.

        :returns X: This type has no constructors.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.layer = layer
        self.query = query

    def on_send(self, writer):
        writer.write_int(InvokeWithLayerRequest.constructor_id, signed=False)
        writer.write_int(self.layer)
        self.query.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return InvokeWithLayerRequest(None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'invokeWithLayer#da9b0d0d {X:Type} layer:int query:!X = X'

    def __str__(self):
        return '(invokeWithLayer (ID: 0xda9b0d0d) = (layer={}, query={}))'.format(str(self.layer), str(self.query))



from ...tl.mtproto_request import MTProtoRequest


class InputMediaVenue(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    inputMediaVenue#2827a81a geo_point:InputGeoPoint title:string address:string provider:string venue_id:string = InputMedia"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x2827a81a

    def __init__(self, geo_point, title, address, provider, venue_id):
        """
        :param geo_point: Telegram type: «InputGeoPoint».
        :param title: Telegram type: «string».
        :param address: Telegram type: «string».
        :param provider: Telegram type: «string».
        :param venue_id: Telegram type: «string».

        Constructor for InputMedia: Instance of either InputMediaEmpty, InputMediaUploadedPhoto, InputMediaPhoto, InputMediaGeoPoint, InputMediaContact, InputMediaUploadedDocument, InputMediaUploadedThumbDocument, InputMediaDocument, InputMediaVenue, InputMediaGifExternal, InputMediaPhotoExternal, InputMediaDocumentExternal, InputMediaGame, InputMediaInvoice.
        """
        super().__init__()

        self.geo_point = geo_point
        self.title = title
        self.address = address
        self.provider = provider
        self.venue_id = venue_id

    def on_send(self, writer):
        writer.write_int(InputMediaVenue.constructor_id, signed=False)
        self.geo_point.on_send(writer)
        writer.tgwrite_string(self.title)
        writer.tgwrite_string(self.address)
        writer.tgwrite_string(self.provider)
        writer.tgwrite_string(self.venue_id)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return InputMediaVenue(None, None, None, None, None)

    def on_response(self, reader):
        self.geo_point = reader.tgread_object()
        self.title = reader.tgread_string()
        self.address = reader.tgread_string()
        self.provider = reader.tgread_string()
        self.venue_id = reader.tgread_string()

    def __repr__(self):
        return 'inputMediaVenue#2827a81a geo_point:InputGeoPoint title:string address:string provider:string venue_id:string = InputMedia'

    def __str__(self):
        return '(inputMediaVenue (ID: 0x2827a81a) = (geo_point={}, title={}, address={}, provider={}, venue_id={}))'.format(str(self.geo_point), str(self.title), str(self.address), str(self.provider), str(self.venue_id))



from ...tl.mtproto_request import MTProtoRequest


class InputBotInlineMessageMediaGeo(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    inputBotInlineMessageMediaGeo#f4a59de1 flags:# geo_point:InputGeoPoint reply_markup:flags.2?ReplyMarkup = InputBotInlineMessage"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xf4a59de1

    def __init__(self, geo_point, reply_markup=None):
        """
        :param geo_point: Telegram type: «InputGeoPoint».
        :param reply_markup: Telegram type: «ReplyMarkup».

        Constructor for InputBotInlineMessage: Instance of either InputBotInlineMessageMediaAuto, InputBotInlineMessageText, InputBotInlineMessageMediaGeo, InputBotInlineMessageMediaVenue, InputBotInlineMessageMediaContact, InputBotInlineMessageGame.
        """
        super().__init__()

        self.geo_point = geo_point
        self.reply_markup = reply_markup

    def on_send(self, writer):
        writer.write_int(InputBotInlineMessageMediaGeo.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 2) if self.reply_markup else 0
        writer.write_int(flags)

        self.geo_point.on_send(writer)
        if self.reply_markup:
            self.reply_markup.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return InputBotInlineMessageMediaGeo(None, None)

    def on_response(self, reader):
        flags = reader.read_int()

        self.geo_point = reader.tgread_object()
        if (flags & (1 << 2)) != 0:
            self.reply_markup = reader.tgread_object()

    def __repr__(self):
        return 'inputBotInlineMessageMediaGeo#f4a59de1 flags:# geo_point:InputGeoPoint reply_markup:flags.2?ReplyMarkup = InputBotInlineMessage'

    def __str__(self):
        return '(inputBotInlineMessageMediaGeo (ID: 0xf4a59de1) = (geo_point={}, reply_markup={}))'.format(str(self.geo_point), str(self.reply_markup))



from ....tl.mtproto_request import MTProtoRequest


class ResolvedPeer(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    contacts.resolvedPeer#7f077ad9 peer:Peer chats:Vector<Chat> users:Vector<User> = contacts.ResolvedPeer"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x7f077ad9

    def __init__(self, peer, chats, users):
        """
        :param peer: Telegram type: «Peer».
        :param chats: Telegram type: «Chat». Must be a list.
        :param users: Telegram type: «User». Must be a list.

        Constructor for contacts.ResolvedPeer: Instance of ResolvedPeer.
        """
        super().__init__()

        self.peer = peer
        self.chats = chats
        self.users = users

    def on_send(self, writer):
        writer.write_int(ResolvedPeer.constructor_id, signed=False)
        self.peer.on_send(writer)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.chats))
        for chats_item in self.chats:
            chats_item.on_send(writer)

        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.users))
        for users_item in self.users:
            users_item.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return ResolvedPeer(None, None, None)

    def on_response(self, reader):
        self.peer = reader.tgread_object()
        reader.read_int()  # Vector's constructor ID
        self.chats = []  # Initialize an empty list
        chats_len = reader.read_int()
        for _ in range(chats_len):
            chats_item = reader.tgread_object()
            self.chats.append(chats_item)

        reader.read_int()  # Vector's constructor ID
        self.users = []  # Initialize an empty list
        users_len = reader.read_int()
        for _ in range(users_len):
            users_item = reader.tgread_object()
            self.users.append(users_item)

    def __repr__(self):
        return 'contacts.resolvedPeer#7f077ad9 peer:Peer chats:Vector<Chat> users:Vector<User> = contacts.ResolvedPeer'

    def __str__(self):
        return '(contacts.resolvedPeer (ID: 0x7f077ad9) = (peer={}, chats={}, users={}))'.format(str(self.peer), None if not self.chats else [str(_) for _ in self.chats], None if not self.users else [str(_) for _ in self.users])



from ...tl.mtproto_request import MTProtoRequest


class EncryptedChatWaiting(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    encryptedChatWaiting#3bf703dc id:int access_hash:long date:date admin_id:int participant_id:int = EncryptedChat"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x3bf703dc

    def __init__(self, id, access_hash, date, admin_id, participant_id):
        """
        :param id: Telegram type: «int».
        :param access_hash: Telegram type: «long».
        :param date: Telegram type: «date».
        :param admin_id: Telegram type: «int».
        :param participant_id: Telegram type: «int».

        Constructor for EncryptedChat: Instance of either EncryptedChatEmpty, EncryptedChatWaiting, EncryptedChatRequested, EncryptedChat, EncryptedChatDiscarded.
        """
        super().__init__()

        self.id = id
        self.access_hash = access_hash
        self.date = date
        self.admin_id = admin_id
        self.participant_id = participant_id

    def on_send(self, writer):
        writer.write_int(EncryptedChatWaiting.constructor_id, signed=False)
        writer.write_int(self.id)
        writer.write_long(self.access_hash)
        writer.tgwrite_date(self.date)
        writer.write_int(self.admin_id)
        writer.write_int(self.participant_id)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return EncryptedChatWaiting(None, None, None, None, None)

    def on_response(self, reader):
        self.id = reader.read_int()
        self.access_hash = reader.read_long()
        self.date = reader.tgread_date()
        self.admin_id = reader.read_int()
        self.participant_id = reader.read_int()

    def __repr__(self):
        return 'encryptedChatWaiting#3bf703dc id:int access_hash:long date:date admin_id:int participant_id:int = EncryptedChat'

    def __str__(self):
        return '(encryptedChatWaiting (ID: 0x3bf703dc) = (id={}, access_hash={}, date={}, admin_id={}, participant_id={}))'.format(str(self.id), str(self.access_hash), str(self.date), str(self.admin_id), str(self.participant_id))



"""Utilities for working with TLObjects.
   We have these because some TLObjects differ in very little things,
   for example, some may have an `user_id` attribute and other a `chat_id` but,
   after all, both are the same attribute, IDs."""
from mimetypes import add_type, guess_extension

from ..tl.types import (
    Channel, Chat, ChatPhoto, InputPeerChannel, InputPeerChat, InputPeerUser,
    MessageMediaDocument, MessageMediaPhoto, PeerChannel, PeerChat, PeerUser,
    User, UserProfilePhoto)


def get_display_name(entity):
    """Gets the input peer for the given "entity" (user, chat or channel)
       Returns None if it was not found"""
    if isinstance(entity, User):
        if entity.last_name is not None:
            return '{} {}'.format(entity.first_name, entity.last_name)
        return entity.first_name

    if isinstance(entity, Chat) or isinstance(entity, Channel):
        return entity.title

    return '(unknown)'

# For some reason, .webp (stickers' format) is not registered
add_type('image/webp', '.webp')


def get_extension(media):
    """Gets the corresponding extension for any Telegram media"""

    # Photos are always compressed as .jpg by Telegram
    if (isinstance(media, UserProfilePhoto) or isinstance(media, ChatPhoto) or
            isinstance(media, MessageMediaPhoto)):
        return '.jpg'

    # Documents will come with a mime type, from which we can guess their mime type
    if isinstance(media, MessageMediaDocument):
        extension = guess_extension(media.document.mime_type)
        return extension if extension else ''

    return None


def get_input_peer(entity):
    """Gets the input peer for the given "entity" (user, chat or channel).
       A ValueError is raised if the given entity isn't a supported type."""
    if (isinstance(entity, InputPeerUser) or
        isinstance(entity, InputPeerChat) or
            isinstance(entity, InputPeerChannel)):
        return entity

    if isinstance(entity, User):
        return InputPeerUser(entity.id, entity.access_hash)
    if isinstance(entity, Chat):
        return InputPeerChat(entity.id)
    if isinstance(entity, Channel):
        return InputPeerChannel(entity.id, entity.access_hash)

    raise ValueError('Cannot cast {} to any kind of InputPeer.'
                     .format(type(entity).__name__))


def find_user_or_chat(peer, users, chats):
    """Finds the corresponding user or chat given a peer.
       Returns None if it was not found"""
    try:
        if isinstance(peer, PeerUser):
            user = next(u for u in users if u.id == peer.user_id)
            return user

        elif isinstance(peer, PeerChat):
            chat = next(c for c in chats if c.id == peer.chat_id)
            return chat

        elif isinstance(peer, PeerChannel):
            channel = next(c for c in chats if c.id == peer.channel_id)
            return channel

    except StopIteration:
        return None


def get_appropriated_part_size(file_size):
    """Gets the appropriated part size when uploading or downloading files,
       given an initial file size"""
    if file_size <= 1048576:  # 1MB
        return 32
    if file_size <= 10485760:  # 10MB
        return 64
    if file_size <= 393216000:  # 375MB
        return 128
    if file_size <= 786432000:  # 750MB
        return 256
    if file_size <= 1572864000:  # 1500MB
        return 512

    raise ValueError('File size too large')



from ...tl.mtproto_request import MTProtoRequest


class PageBlockPhoto(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    pageBlockPhoto#e9c69982 photo_id:long caption:RichText = PageBlock"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xe9c69982

    def __init__(self, photo_id, caption):
        """
        :param photo_id: Telegram type: «long».
        :param caption: Telegram type: «RichText».

        Constructor for PageBlock: Instance of either PageBlockUnsupported, PageBlockTitle, PageBlockSubtitle, PageBlockAuthorDate, PageBlockHeader, PageBlockSubheader, PageBlockParagraph, PageBlockPreformatted, PageBlockFooter, PageBlockDivider, PageBlockAnchor, PageBlockList, PageBlockBlockquote, PageBlockPullquote, PageBlockPhoto, PageBlockVideo, PageBlockCover, PageBlockEmbed, PageBlockEmbedPost, PageBlockCollage, PageBlockSlideshow, PageBlockChannel.
        """
        super().__init__()

        self.photo_id = photo_id
        self.caption = caption

    def on_send(self, writer):
        writer.write_int(PageBlockPhoto.constructor_id, signed=False)
        writer.write_long(self.photo_id)
        self.caption.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return PageBlockPhoto(None, None)

    def on_response(self, reader):
        self.photo_id = reader.read_long()
        self.caption = reader.tgread_object()

    def __repr__(self):
        return 'pageBlockPhoto#e9c69982 photo_id:long caption:RichText = PageBlock'

    def __str__(self):
        return '(pageBlockPhoto (ID: 0xe9c69982) = (photo_id={}, caption={}))'.format(str(self.photo_id), str(self.caption))



from ...tl.mtproto_request import MTProtoRequest


class Chat(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    chat#d91cdd54 flags:# creator:flags.0?true kicked:flags.1?true left:flags.2?true admins_enabled:flags.3?true admin:flags.4?true deactivated:flags.5?true id:int title:string photo:ChatPhoto participants_count:int date:date version:int migrated_to:flags.6?InputChannel = Chat"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xd91cdd54

    def __init__(self, id, title, photo, participants_count, date, version, creator=None, kicked=None, left=None, admins_enabled=None, admin=None, deactivated=None, migrated_to=None):
        """
        :param creator: Telegram type: «true».
        :param kicked: Telegram type: «true».
        :param left: Telegram type: «true».
        :param admins_enabled: Telegram type: «true».
        :param admin: Telegram type: «true».
        :param deactivated: Telegram type: «true».
        :param id: Telegram type: «int».
        :param title: Telegram type: «string».
        :param photo: Telegram type: «ChatPhoto».
        :param participants_count: Telegram type: «int».
        :param date: Telegram type: «date».
        :param version: Telegram type: «int».
        :param migrated_to: Telegram type: «InputChannel».

        Constructor for Chat: Instance of either ChatEmpty, Chat, ChatForbidden, Channel, ChannelForbidden.
        """
        super().__init__()

        self.creator = creator
        self.kicked = kicked
        self.left = left
        self.admins_enabled = admins_enabled
        self.admin = admin
        self.deactivated = deactivated
        self.id = id
        self.title = title
        self.photo = photo
        self.participants_count = participants_count
        self.date = date
        self.version = version
        self.migrated_to = migrated_to

    def on_send(self, writer):
        writer.write_int(Chat.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.creator else 0
        flags |= (1 << 1) if self.kicked else 0
        flags |= (1 << 2) if self.left else 0
        flags |= (1 << 3) if self.admins_enabled else 0
        flags |= (1 << 4) if self.admin else 0
        flags |= (1 << 5) if self.deactivated else 0
        flags |= (1 << 6) if self.migrated_to else 0
        writer.write_int(flags)

        writer.write_int(self.id)
        writer.tgwrite_string(self.title)
        self.photo.on_send(writer)
        writer.write_int(self.participants_count)
        writer.tgwrite_date(self.date)
        writer.write_int(self.version)
        if self.migrated_to:
            self.migrated_to.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return Chat(None, None, None, None, None, None, None, None, None, None, None, None, None)

    def on_response(self, reader):
        flags = reader.read_int()

        if (flags & (1 << 0)) != 0:
            self.creator = True  # Arbitrary not-None value, no need to read since it is a flag

        if (flags & (1 << 1)) != 0:
            self.kicked = True  # Arbitrary not-None value, no need to read since it is a flag

        if (flags & (1 << 2)) != 0:
            self.left = True  # Arbitrary not-None value, no need to read since it is a flag

        if (flags & (1 << 3)) != 0:
            self.admins_enabled = True  # Arbitrary not-None value, no need to read since it is a flag

        if (flags & (1 << 4)) != 0:
            self.admin = True  # Arbitrary not-None value, no need to read since it is a flag

        if (flags & (1 << 5)) != 0:
            self.deactivated = True  # Arbitrary not-None value, no need to read since it is a flag

        self.id = reader.read_int()
        self.title = reader.tgread_string()
        self.photo = reader.tgread_object()
        self.participants_count = reader.read_int()
        self.date = reader.tgread_date()
        self.version = reader.read_int()
        if (flags & (1 << 6)) != 0:
            self.migrated_to = reader.tgread_object()

    def __repr__(self):
        return 'chat#d91cdd54 flags:# creator:flags.0?true kicked:flags.1?true left:flags.2?true admins_enabled:flags.3?true admin:flags.4?true deactivated:flags.5?true id:int title:string photo:ChatPhoto participants_count:int date:date version:int migrated_to:flags.6?InputChannel = Chat'

    def __str__(self):
        return '(chat (ID: 0xd91cdd54) = (creator={}, kicked={}, left={}, admins_enabled={}, admin={}, deactivated={}, id={}, title={}, photo={}, participants_count={}, date={}, version={}, migrated_to={}))'.format(str(self.creator), str(self.kicked), str(self.left), str(self.admins_enabled), str(self.admin), str(self.deactivated), str(self.id), str(self.title), str(self.photo), str(self.participants_count), str(self.date), str(self.version), str(self.migrated_to))



from ....tl.mtproto_request import MTProtoRequest


class GetChannelDifferenceRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updates.getChannelDifference#03173d78 flags:# force:flags.0?true channel:InputChannel filter:ChannelMessagesFilter pts:int limit:int = updates.ChannelDifference"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x3173d78

    def __init__(self, channel, filter, pts, limit, force=None):
        """
        :param force: Telegram type: «true».
        :param channel: Telegram type: «InputChannel».
        :param filter: Telegram type: «ChannelMessagesFilter».
        :param pts: Telegram type: «int».
        :param limit: Telegram type: «int».

        :returns updates.ChannelDifference: Instance of either ChannelDifferenceEmpty, ChannelDifferenceTooLong, ChannelDifference.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.force = force
        self.channel = channel
        self.filter = filter
        self.pts = pts
        self.limit = limit

    def on_send(self, writer):
        writer.write_int(GetChannelDifferenceRequest.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.force else 0
        writer.write_int(flags)

        self.channel.on_send(writer)
        self.filter.on_send(writer)
        writer.write_int(self.pts)
        writer.write_int(self.limit)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return GetChannelDifferenceRequest(None, None, None, None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'updates.getChannelDifference#03173d78 flags:# force:flags.0?true channel:InputChannel filter:ChannelMessagesFilter pts:int limit:int = updates.ChannelDifference'

    def __str__(self):
        return '(updates.getChannelDifference (ID: 0x3173d78) = (force={}, channel={}, filter={}, pts={}, limit={}))'.format(str(self.force), str(self.channel), str(self.filter), str(self.pts), str(self.limit))



from ....tl.mtproto_request import MTProtoRequest


class CheckedPhone(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    auth.checkedPhone#811ea28e phone_registered:Bool = auth.CheckedPhone"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x811ea28e

    def __init__(self, phone_registered):
        """
        :param phone_registered: Telegram type: «Bool».

        Constructor for auth.CheckedPhone: Instance of CheckedPhone.
        """
        super().__init__()

        self.phone_registered = phone_registered

    def on_send(self, writer):
        writer.write_int(CheckedPhone.constructor_id, signed=False)
        writer.tgwrite_bool(self.phone_registered)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return CheckedPhone(None)

    def on_response(self, reader):
        self.phone_registered = reader.tgread_bool()

    def __repr__(self):
        return 'auth.checkedPhone#811ea28e phone_registered:Bool = auth.CheckedPhone'

    def __str__(self):
        return '(auth.checkedPhone (ID: 0x811ea28e) = (phone_registered={}))'.format(str(self.phone_registered))



from ...tl.mtproto_request import MTProtoRequest


class UpdateDialogPinned(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateDialogPinned#d711a2cc flags:# pinned:flags.0?true peer:Peer = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xd711a2cc

    def __init__(self, peer, pinned=None):
        """
        :param pinned: Telegram type: «true».
        :param peer: Telegram type: «Peer».

        Constructor for Update: Instance of either UpdateNewMessage, UpdateMessageID, UpdateDeleteMessages, UpdateUserTyping, UpdateChatUserTyping, UpdateChatParticipants, UpdateUserStatus, UpdateUserName, UpdateUserPhoto, UpdateContactRegistered, UpdateContactLink, UpdateNewEncryptedMessage, UpdateEncryptedChatTyping, UpdateEncryption, UpdateEncryptedMessagesRead, UpdateChatParticipantAdd, UpdateChatParticipantDelete, UpdateDcOptions, UpdateUserBlocked, UpdateNotifySettings, UpdateServiceNotification, UpdatePrivacy, UpdateUserPhone, UpdateReadHistoryInbox, UpdateReadHistoryOutbox, UpdateWebPage, UpdateReadMessagesContents, UpdateChannelTooLong, UpdateChannel, UpdateNewChannelMessage, UpdateReadChannelInbox, UpdateDeleteChannelMessages, UpdateChannelMessageViews, UpdateChatAdmins, UpdateChatParticipantAdmin, UpdateNewStickerSet, UpdateStickerSetsOrder, UpdateStickerSets, UpdateSavedGifs, UpdateBotInlineQuery, UpdateBotInlineSend, UpdateEditChannelMessage, UpdateChannelPinnedMessage, UpdateBotCallbackQuery, UpdateEditMessage, UpdateInlineBotCallbackQuery, UpdateReadChannelOutbox, UpdateDraftMessage, UpdateReadFeaturedStickers, UpdateRecentStickers, UpdateConfig, UpdatePtsChanged, UpdateChannelWebPage, UpdateDialogPinned, UpdatePinnedDialogs, UpdateBotWebhookJSON, UpdateBotWebhookJSONQuery, UpdateBotShippingQuery, UpdateBotPrecheckoutQuery, UpdatePhoneCall.
        """
        super().__init__()

        self.pinned = pinned
        self.peer = peer

    def on_send(self, writer):
        writer.write_int(UpdateDialogPinned.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.pinned else 0
        writer.write_int(flags)

        self.peer.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateDialogPinned(None, None)

    def on_response(self, reader):
        flags = reader.read_int()

        if (flags & (1 << 0)) != 0:
            self.pinned = True  # Arbitrary not-None value, no need to read since it is a flag

        self.peer = reader.tgread_object()

    def __repr__(self):
        return 'updateDialogPinned#d711a2cc flags:# pinned:flags.0?true peer:Peer = Update'

    def __str__(self):
        return '(updateDialogPinned (ID: 0xd711a2cc) = (pinned={}, peer={}))'.format(str(self.pinned), str(self.peer))



from ....tl.mtproto_request import MTProtoRequest


class GetFullUserRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    users.getFullUser#ca30a5b1 id:InputUser = UserFull"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xca30a5b1

    def __init__(self, id):
        """
        :param id: Telegram type: «InputUser».

        :returns UserFull: Instance of UserFull.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.id = id

    def on_send(self, writer):
        writer.write_int(GetFullUserRequest.constructor_id, signed=False)
        self.id.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return GetFullUserRequest(None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'users.getFullUser#ca30a5b1 id:InputUser = UserFull'

    def __str__(self):
        return '(users.getFullUser (ID: 0xca30a5b1) = (id={}))'.format(str(self.id))



from ...tl.mtproto_request import MTProtoRequest


class HighScore(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    highScore#58fffcd0 pos:int user_id:int score:int = HighScore"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x58fffcd0

    def __init__(self, pos, user_id, score):
        """
        :param pos: Telegram type: «int».
        :param user_id: Telegram type: «int».
        :param score: Telegram type: «int».

        Constructor for HighScore: Instance of HighScore.
        """
        super().__init__()

        self.pos = pos
        self.user_id = user_id
        self.score = score

    def on_send(self, writer):
        writer.write_int(HighScore.constructor_id, signed=False)
        writer.write_int(self.pos)
        writer.write_int(self.user_id)
        writer.write_int(self.score)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return HighScore(None, None, None)

    def on_response(self, reader):
        self.pos = reader.read_int()
        self.user_id = reader.read_int()
        self.score = reader.read_int()

    def __repr__(self):
        return 'highScore#58fffcd0 pos:int user_id:int score:int = HighScore'

    def __str__(self):
        return '(highScore (ID: 0x58fffcd0) = (pos={}, user_id={}, score={}))'.format(str(self.pos), str(self.user_id), str(self.score))



from ....tl.mtproto_request import MTProtoRequest


class ResetAuthorizationRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    account.resetAuthorization#df77f3bc hash:long = Bool"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xdf77f3bc

    def __init__(self, hash):
        """
        :param hash: Telegram type: «long».

        :returns Bool: This type has no constructors.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.hash = hash

    def on_send(self, writer):
        writer.write_int(ResetAuthorizationRequest.constructor_id, signed=False)
        writer.write_long(self.hash)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return ResetAuthorizationRequest(None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'account.resetAuthorization#df77f3bc hash:long = Bool'

    def __str__(self):
        return '(account.resetAuthorization (ID: 0xdf77f3bc) = (hash={}))'.format(str(self.hash))



from ....tl.mtproto_request import MTProtoRequest


class UploadProfilePhotoRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    photos.uploadProfilePhoto#4f32c098 file:InputFile = photos.Photo"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x4f32c098

    def __init__(self, file):
        """
        :param file: Telegram type: «InputFile».

        :returns photos.Photo: Instance of Photo.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.file = file

    def on_send(self, writer):
        writer.write_int(UploadProfilePhotoRequest.constructor_id, signed=False)
        self.file.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UploadProfilePhotoRequest(None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'photos.uploadProfilePhoto#4f32c098 file:InputFile = photos.Photo'

    def __str__(self):
        return '(photos.uploadProfilePhoto (ID: 0x4f32c098) = (file={}))'.format(str(self.file))



from ...tl.mtproto_request import MTProtoRequest


class TextPlain(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    textPlain#744694e0 text:string = RichText"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x744694e0

    def __init__(self, text):
        """
        :param text: Telegram type: «string».

        Constructor for RichText: Instance of either TextEmpty, TextPlain, TextBold, TextItalic, TextUnderline, TextStrike, TextFixed, TextUrl, TextEmail, TextConcat.
        """
        super().__init__()

        self.text = text

    def on_send(self, writer):
        writer.write_int(TextPlain.constructor_id, signed=False)
        writer.tgwrite_string(self.text)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return TextPlain(None)

    def on_response(self, reader):
        self.text = reader.tgread_string()

    def __repr__(self):
        return 'textPlain#744694e0 text:string = RichText'

    def __str__(self):
        return '(textPlain (ID: 0x744694e0) = (text={}))'.format(str(self.text))



from .register_device import RegisterDeviceRequest
from .unregister_device import UnregisterDeviceRequest
from .update_notify_settings import UpdateNotifySettingsRequest
from .get_notify_settings import GetNotifySettingsRequest
from .reset_notify_settings import ResetNotifySettingsRequest
from .update_profile import UpdateProfileRequest
from .update_status import UpdateStatusRequest
from .get_wall_papers import GetWallPapersRequest
from .report_peer import ReportPeerRequest
from .check_username import CheckUsernameRequest
from .update_username import UpdateUsernameRequest
from .get_privacy import GetPrivacyRequest
from .set_privacy import SetPrivacyRequest
from .delete_account import DeleteAccountRequest
from .get_account_ttl import GetAccountTTLRequest
from .set_account_ttl import SetAccountTTLRequest
from .send_change_phone_code import SendChangePhoneCodeRequest
from .change_phone import ChangePhoneRequest
from .update_device_locked import UpdateDeviceLockedRequest
from .get_authorizations import GetAuthorizationsRequest
from .reset_authorization import ResetAuthorizationRequest
from .get_password import GetPasswordRequest
from .get_password_settings import GetPasswordSettingsRequest
from .update_password_settings import UpdatePasswordSettingsRequest
from .send_confirm_phone_code import SendConfirmPhoneCodeRequest
from .confirm_phone import ConfirmPhoneRequest
from .get_tmp_password import GetTmpPasswordRequest



from ....tl.mtproto_request import MTProtoRequest


class InviteText(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    help.inviteText#18cb9f78 message:string = help.InviteText"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x18cb9f78

    def __init__(self, message):
        """
        :param message: Telegram type: «string».

        Constructor for help.InviteText: Instance of InviteText.
        """
        super().__init__()

        self.message = message

    def on_send(self, writer):
        writer.write_int(InviteText.constructor_id, signed=False)
        writer.tgwrite_string(self.message)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return InviteText(None)

    def on_response(self, reader):
        self.message = reader.tgread_string()

    def __repr__(self):
        return 'help.inviteText#18cb9f78 message:string = help.InviteText'

    def __str__(self):
        return '(help.inviteText (ID: 0x18cb9f78) = (message={}))'.format(str(self.message))



from ....tl.mtproto_request import MTProtoRequest


class SendCodeRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    auth.sendCode#86aef0ec flags:# allow_flashcall:flags.0?true phone_number:string current_number:flags.0?Bool api_id:int api_hash:string = auth.SentCode"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x86aef0ec

    def __init__(self, phone_number, api_id, api_hash, allow_flashcall=None, current_number=None):
        """
        :param allow_flashcall: Telegram type: «true».
        :param phone_number: Telegram type: «string».
        :param current_number: Telegram type: «Bool».
        :param api_id: Telegram type: «int».
        :param api_hash: Telegram type: «string».

        :returns auth.SentCode: Instance of SentCode.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.allow_flashcall = allow_flashcall
        self.phone_number = phone_number
        self.current_number = current_number
        self.api_id = api_id
        self.api_hash = api_hash

    def on_send(self, writer):
        writer.write_int(SendCodeRequest.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.allow_flashcall else 0
        flags |= (1 << 0) if self.current_number else 0
        writer.write_int(flags)

        writer.tgwrite_string(self.phone_number)
        if self.current_number:
            writer.tgwrite_bool(self.current_number)

        writer.write_int(self.api_id)
        writer.tgwrite_string(self.api_hash)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return SendCodeRequest(None, None, None, None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'auth.sendCode#86aef0ec flags:# allow_flashcall:flags.0?true phone_number:string current_number:flags.0?Bool api_id:int api_hash:string = auth.SentCode'

    def __str__(self):
        return '(auth.sendCode (ID: 0x86aef0ec) = (allow_flashcall={}, phone_number={}, current_number={}, api_id={}, api_hash={}))'.format(str(self.allow_flashcall), str(self.phone_number), str(self.current_number), str(self.api_id), str(self.api_hash))



from ....tl.mtproto_request import MTProtoRequest


class ChannelParticipants(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    channels.channelParticipants#f56ee2a8 count:int participants:Vector<ChannelParticipant> users:Vector<User> = channels.ChannelParticipants"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xf56ee2a8

    def __init__(self, count, participants, users):
        """
        :param count: Telegram type: «int».
        :param participants: Telegram type: «ChannelParticipant». Must be a list.
        :param users: Telegram type: «User». Must be a list.

        Constructor for channels.ChannelParticipants: Instance of ChannelParticipants.
        """
        super().__init__()

        self.count = count
        self.participants = participants
        self.users = users

    def on_send(self, writer):
        writer.write_int(ChannelParticipants.constructor_id, signed=False)
        writer.write_int(self.count)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.participants))
        for participants_item in self.participants:
            participants_item.on_send(writer)

        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.users))
        for users_item in self.users:
            users_item.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return ChannelParticipants(None, None, None)

    def on_response(self, reader):
        self.count = reader.read_int()
        reader.read_int()  # Vector's constructor ID
        self.participants = []  # Initialize an empty list
        participants_len = reader.read_int()
        for _ in range(participants_len):
            participants_item = reader.tgread_object()
            self.participants.append(participants_item)

        reader.read_int()  # Vector's constructor ID
        self.users = []  # Initialize an empty list
        users_len = reader.read_int()
        for _ in range(users_len):
            users_item = reader.tgread_object()
            self.users.append(users_item)

    def __repr__(self):
        return 'channels.channelParticipants#f56ee2a8 count:int participants:Vector<ChannelParticipant> users:Vector<User> = channels.ChannelParticipants'

    def __str__(self):
        return '(channels.channelParticipants (ID: 0xf56ee2a8) = (count={}, participants={}, users={}))'.format(str(self.count), None if not self.participants else [str(_) for _ in self.participants], None if not self.users else [str(_) for _ in self.users])



from ...tl.mtproto_request import MTProtoRequest


class InvokeAfterMsgsRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    invokeAfterMsgs#3dc4b4f0 {X:Type} msg_ids:Vector<long> query:!X = X"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x3dc4b4f0

    def __init__(self, msg_ids, query):
        """
        :param msg_ids: Telegram type: «long». Must be a list.
        :param query: Telegram type: «X». This should be another MTProtoRequest.

        :returns X: This type has no constructors.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.msg_ids = msg_ids
        self.query = query

    def on_send(self, writer):
        writer.write_int(InvokeAfterMsgsRequest.constructor_id, signed=False)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.msg_ids))
        for msg_ids_item in self.msg_ids:
            writer.write_long(msg_ids_item)

        self.query.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return InvokeAfterMsgsRequest(None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'invokeAfterMsgs#3dc4b4f0 {X:Type} msg_ids:Vector<long> query:!X = X'

    def __str__(self):
        return '(invokeAfterMsgs (ID: 0x3dc4b4f0) = (msg_ids={}, query={}))'.format(None if not self.msg_ids else [str(_) for _ in self.msg_ids], str(self.query))



from ....tl.mtproto_request import MTProtoRequest


class GetStickerSetRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.getStickerSet#2619a90e stickerset:InputStickerSet = messages.StickerSet"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x2619a90e

    def __init__(self, stickerset):
        """
        :param stickerset: Telegram type: «InputStickerSet».

        :returns messages.StickerSet: Instance of StickerSet.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.stickerset = stickerset

    def on_send(self, writer):
        writer.write_int(GetStickerSetRequest.constructor_id, signed=False)
        self.stickerset.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return GetStickerSetRequest(None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'messages.getStickerSet#2619a90e stickerset:InputStickerSet = messages.StickerSet'

    def __str__(self):
        return '(messages.getStickerSet (ID: 0x2619a90e) = (stickerset={}))'.format(str(self.stickerset))



from ....tl.mtproto_request import MTProtoRequest


class EditAdminRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    channels.editAdmin#eb7611d0 channel:InputChannel user_id:InputUser role:ChannelParticipantRole = Updates"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xeb7611d0

    def __init__(self, channel, user_id, role):
        """
        :param channel: Telegram type: «InputChannel».
        :param user_id: Telegram type: «InputUser».
        :param role: Telegram type: «ChannelParticipantRole».

        :returns Updates: Instance of either UpdatesTooLong, UpdateShortMessage, UpdateShortChatMessage, UpdateShort, UpdatesCombined, UpdatesTg, UpdateShortSentMessage.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.channel = channel
        self.user_id = user_id
        self.role = role

    def on_send(self, writer):
        writer.write_int(EditAdminRequest.constructor_id, signed=False)
        self.channel.on_send(writer)
        self.user_id.on_send(writer)
        self.role.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return EditAdminRequest(None, None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'channels.editAdmin#eb7611d0 channel:InputChannel user_id:InputUser role:ChannelParticipantRole = Updates'

    def __str__(self):
        return '(channels.editAdmin (ID: 0xeb7611d0) = (channel={}, user_id={}, role={}))'.format(str(self.channel), str(self.user_id), str(self.role))



from ...tl.mtproto_request import MTProtoRequest


class WebPagePending(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    webPagePending#c586da1c id:long date:date = WebPage"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xc586da1c

    def __init__(self, id, date):
        """
        :param id: Telegram type: «long».
        :param date: Telegram type: «date».

        Constructor for WebPage: Instance of either WebPageEmpty, WebPagePending, WebPage, WebPageNotModified.
        """
        super().__init__()

        self.id = id
        self.date = date

    def on_send(self, writer):
        writer.write_int(WebPagePending.constructor_id, signed=False)
        writer.write_long(self.id)
        writer.tgwrite_date(self.date)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return WebPagePending(None, None)

    def on_response(self, reader):
        self.id = reader.read_long()
        self.date = reader.tgread_date()

    def __repr__(self):
        return 'webPagePending#c586da1c id:long date:date = WebPage'

    def __str__(self):
        return '(webPagePending (ID: 0xc586da1c) = (id={}, date={}))'.format(str(self.id), str(self.date))



from ....tl.mtproto_request import MTProtoRequest


class SetBotShippingResultsRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.setBotShippingResults#e5f672fa flags:# query_id:long error:flags.0?string shipping_options:flags.1?Vector<ShippingOption> = Bool"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xe5f672fa

    def __init__(self, query_id, error=None, shipping_options=None):
        """
        :param query_id: Telegram type: «long».
        :param error: Telegram type: «string».
        :param shipping_options: Telegram type: «ShippingOption». Must be a list.

        :returns Bool: This type has no constructors.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.query_id = query_id
        self.error = error
        self.shipping_options = shipping_options

    def on_send(self, writer):
        writer.write_int(SetBotShippingResultsRequest.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.error else 0
        flags |= (1 << 1) if self.shipping_options else 0
        writer.write_int(flags)

        writer.write_long(self.query_id)
        if self.error:
            writer.tgwrite_string(self.error)

        if self.shipping_options:
            writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
            writer.write_int(len(self.shipping_options))
            for shipping_options_item in self.shipping_options:
                if shipping_options_item:
                    shipping_options_item.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return SetBotShippingResultsRequest(None, None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'messages.setBotShippingResults#e5f672fa flags:# query_id:long error:flags.0?string shipping_options:flags.1?Vector<ShippingOption> = Bool'

    def __str__(self):
        return '(messages.setBotShippingResults (ID: 0xe5f672fa) = (query_id={}, error={}, shipping_options={}))'.format(str(self.query_id), str(self.error), None if not self.shipping_options else [str(_) for _ in self.shipping_options])



from ....tl.mtproto_request import MTProtoRequest


class DeleteAccountRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    account.deleteAccount#418d4e0b reason:string = Bool"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x418d4e0b

    def __init__(self, reason):
        """
        :param reason: Telegram type: «string».

        :returns Bool: This type has no constructors.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.reason = reason

    def on_send(self, writer):
        writer.write_int(DeleteAccountRequest.constructor_id, signed=False)
        writer.tgwrite_string(self.reason)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return DeleteAccountRequest(None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'account.deleteAccount#418d4e0b reason:string = Bool'

    def __str__(self):
        return '(account.deleteAccount (ID: 0x418d4e0b) = (reason={}))'.format(str(self.reason))



from ...tl.mtproto_request import MTProtoRequest


class TextEmail(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    textEmail#de5a0dd6 text:RichText email:string = RichText"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xde5a0dd6

    def __init__(self, text, email):
        """
        :param text: Telegram type: «RichText».
        :param email: Telegram type: «string».

        Constructor for RichText: Instance of either TextEmpty, TextPlain, TextBold, TextItalic, TextUnderline, TextStrike, TextFixed, TextUrl, TextEmail, TextConcat.
        """
        super().__init__()

        self.text = text
        self.email = email

    def on_send(self, writer):
        writer.write_int(TextEmail.constructor_id, signed=False)
        self.text.on_send(writer)
        writer.tgwrite_string(self.email)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return TextEmail(None, None)

    def on_response(self, reader):
        self.text = reader.tgread_object()
        self.email = reader.tgread_string()

    def __repr__(self):
        return 'textEmail#de5a0dd6 text:RichText email:string = RichText'

    def __str__(self):
        return '(textEmail (ID: 0xde5a0dd6) = (text={}, email={}))'.format(str(self.text), str(self.email))



from ...tl.mtproto_request import MTProtoRequest


class ShippingOption(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    shippingOption#b6213cdf id:string title:string prices:Vector<LabeledPrice> = ShippingOption"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xb6213cdf

    def __init__(self, id, title, prices):
        """
        :param id: Telegram type: «string».
        :param title: Telegram type: «string».
        :param prices: Telegram type: «LabeledPrice». Must be a list.

        Constructor for ShippingOption: Instance of ShippingOption.
        """
        super().__init__()

        self.id = id
        self.title = title
        self.prices = prices

    def on_send(self, writer):
        writer.write_int(ShippingOption.constructor_id, signed=False)
        writer.tgwrite_string(self.id)
        writer.tgwrite_string(self.title)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.prices))
        for prices_item in self.prices:
            prices_item.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return ShippingOption(None, None, None)

    def on_response(self, reader):
        self.id = reader.tgread_string()
        self.title = reader.tgread_string()
        reader.read_int()  # Vector's constructor ID
        self.prices = []  # Initialize an empty list
        prices_len = reader.read_int()
        for _ in range(prices_len):
            prices_item = reader.tgread_object()
            self.prices.append(prices_item)

    def __repr__(self):
        return 'shippingOption#b6213cdf id:string title:string prices:Vector<LabeledPrice> = ShippingOption'

    def __str__(self):
        return '(shippingOption (ID: 0xb6213cdf) = (id={}, title={}, prices={}))'.format(str(self.id), str(self.title), None if not self.prices else [str(_) for _ in self.prices])



from ....tl.mtproto_request import MTProtoRequest


class CreateChatRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.createChat#09cb126e users:Vector<InputUser> title:string = Updates"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x9cb126e

    def __init__(self, users, title):
        """
        :param users: Telegram type: «InputUser». Must be a list.
        :param title: Telegram type: «string».

        :returns Updates: Instance of either UpdatesTooLong, UpdateShortMessage, UpdateShortChatMessage, UpdateShort, UpdatesCombined, UpdatesTg, UpdateShortSentMessage.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.users = users
        self.title = title

    def on_send(self, writer):
        writer.write_int(CreateChatRequest.constructor_id, signed=False)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.users))
        for users_item in self.users:
            users_item.on_send(writer)

        writer.tgwrite_string(self.title)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return CreateChatRequest(None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'messages.createChat#09cb126e users:Vector<InputUser> title:string = Updates'

    def __str__(self):
        return '(messages.createChat (ID: 0x9cb126e) = (users={}, title={}))'.format(None if not self.users else [str(_) for _ in self.users], str(self.title))



from ....tl.mtproto_request import MTProtoRequest


class WebFile(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    upload.webFile#21e753bc size:int mime_type:string file_type:storage.FileType mtime:int bytes:bytes = upload.WebFile"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x21e753bc

    def __init__(self, size, mime_type, file_type, mtime, bytes):
        """
        :param size: Telegram type: «int».
        :param mime_type: Telegram type: «string».
        :param file_type: Telegram type: «storage.FileType».
        :param mtime: Telegram type: «int».
        :param bytes: Telegram type: «bytes».

        Constructor for upload.WebFile: Instance of WebFile.
        """
        super().__init__()

        self.size = size
        self.mime_type = mime_type
        self.file_type = file_type
        self.mtime = mtime
        self.bytes = bytes

    def on_send(self, writer):
        writer.write_int(WebFile.constructor_id, signed=False)
        writer.write_int(self.size)
        writer.tgwrite_string(self.mime_type)
        self.file_type.on_send(writer)
        writer.write_int(self.mtime)
        writer.tgwrite_bytes(self.bytes)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return WebFile(None, None, None, None, None)

    def on_response(self, reader):
        self.size = reader.read_int()
        self.mime_type = reader.tgread_string()
        self.file_type = reader.tgread_object()
        self.mtime = reader.read_int()
        self.bytes = reader.tgread_bytes()

    def __repr__(self):
        return 'upload.webFile#21e753bc size:int mime_type:string file_type:storage.FileType mtime:int bytes:bytes = upload.WebFile'

    def __str__(self):
        return '(upload.webFile (ID: 0x21e753bc) = (size={}, mime_type={}, file_type={}, mtime={}, bytes={}))'.format(str(self.size), str(self.mime_type), str(self.file_type), str(self.mtime), str(self.bytes))



from ...tl.mtproto_request import MTProtoRequest


class PageBlockSlideshow(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    pageBlockSlideshow#130c8963 items:Vector<PageBlock> caption:RichText = PageBlock"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x130c8963

    def __init__(self, items, caption):
        """
        :param items: Telegram type: «PageBlock». Must be a list.
        :param caption: Telegram type: «RichText».

        Constructor for PageBlock: Instance of either PageBlockUnsupported, PageBlockTitle, PageBlockSubtitle, PageBlockAuthorDate, PageBlockHeader, PageBlockSubheader, PageBlockParagraph, PageBlockPreformatted, PageBlockFooter, PageBlockDivider, PageBlockAnchor, PageBlockList, PageBlockBlockquote, PageBlockPullquote, PageBlockPhoto, PageBlockVideo, PageBlockCover, PageBlockEmbed, PageBlockEmbedPost, PageBlockCollage, PageBlockSlideshow, PageBlockChannel.
        """
        super().__init__()

        self.items = items
        self.caption = caption

    def on_send(self, writer):
        writer.write_int(PageBlockSlideshow.constructor_id, signed=False)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.items))
        for items_item in self.items:
            items_item.on_send(writer)

        self.caption.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return PageBlockSlideshow(None, None)

    def on_response(self, reader):
        reader.read_int()  # Vector's constructor ID
        self.items = []  # Initialize an empty list
        items_len = reader.read_int()
        for _ in range(items_len):
            items_item = reader.tgread_object()
            self.items.append(items_item)

        self.caption = reader.tgread_object()

    def __repr__(self):
        return 'pageBlockSlideshow#130c8963 items:Vector<PageBlock> caption:RichText = PageBlock'

    def __str__(self):
        return '(pageBlockSlideshow (ID: 0x130c8963) = (items={}, caption={}))'.format(None if not self.items else [str(_) for _ in self.items], str(self.caption))



from ...tl.mtproto_request import MTProtoRequest


class UpdateUserStatus(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateUserStatus#1bfbd823 user_id:int status:UserStatus = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x1bfbd823

    def __init__(self, user_id, status):
        """
        :param user_id: Telegram type: «int».
        :param status: Telegram type: «UserStatus».

        Constructor for Update: Instance of either UpdateNewMessage, UpdateMessageID, UpdateDeleteMessages, UpdateUserTyping, UpdateChatUserTyping, UpdateChatParticipants, UpdateUserStatus, UpdateUserName, UpdateUserPhoto, UpdateContactRegistered, UpdateContactLink, UpdateNewEncryptedMessage, UpdateEncryptedChatTyping, UpdateEncryption, UpdateEncryptedMessagesRead, UpdateChatParticipantAdd, UpdateChatParticipantDelete, UpdateDcOptions, UpdateUserBlocked, UpdateNotifySettings, UpdateServiceNotification, UpdatePrivacy, UpdateUserPhone, UpdateReadHistoryInbox, UpdateReadHistoryOutbox, UpdateWebPage, UpdateReadMessagesContents, UpdateChannelTooLong, UpdateChannel, UpdateNewChannelMessage, UpdateReadChannelInbox, UpdateDeleteChannelMessages, UpdateChannelMessageViews, UpdateChatAdmins, UpdateChatParticipantAdmin, UpdateNewStickerSet, UpdateStickerSetsOrder, UpdateStickerSets, UpdateSavedGifs, UpdateBotInlineQuery, UpdateBotInlineSend, UpdateEditChannelMessage, UpdateChannelPinnedMessage, UpdateBotCallbackQuery, UpdateEditMessage, UpdateInlineBotCallbackQuery, UpdateReadChannelOutbox, UpdateDraftMessage, UpdateReadFeaturedStickers, UpdateRecentStickers, UpdateConfig, UpdatePtsChanged, UpdateChannelWebPage, UpdateDialogPinned, UpdatePinnedDialogs, UpdateBotWebhookJSON, UpdateBotWebhookJSONQuery, UpdateBotShippingQuery, UpdateBotPrecheckoutQuery, UpdatePhoneCall.
        """
        super().__init__()

        self.user_id = user_id
        self.status = status

    def on_send(self, writer):
        writer.write_int(UpdateUserStatus.constructor_id, signed=False)
        writer.write_int(self.user_id)
        self.status.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateUserStatus(None, None)

    def on_response(self, reader):
        self.user_id = reader.read_int()
        self.status = reader.tgread_object()

    def __repr__(self):
        return 'updateUserStatus#1bfbd823 user_id:int status:UserStatus = Update'

    def __str__(self):
        return '(updateUserStatus (ID: 0x1bfbd823) = (user_id={}, status={}))'.format(str(self.user_id), str(self.status))



from ...tl.mtproto_request import MTProtoRequest


class UpdateShort(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateShort#78d4dec1 update:Update date:date = Updates"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x78d4dec1

    def __init__(self, update, date):
        """
        :param update: Telegram type: «Update».
        :param date: Telegram type: «date».

        Constructor for Updates: Instance of either UpdatesTooLong, UpdateShortMessage, UpdateShortChatMessage, UpdateShort, UpdatesCombined, UpdatesTg, UpdateShortSentMessage.
        """
        super().__init__()

        self.update = update
        self.date = date

    def on_send(self, writer):
        writer.write_int(UpdateShort.constructor_id, signed=False)
        self.update.on_send(writer)
        writer.tgwrite_date(self.date)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateShort(None, None)

    def on_response(self, reader):
        self.update = reader.tgread_object()
        self.date = reader.tgread_date()

    def __repr__(self):
        return 'updateShort#78d4dec1 update:Update date:date = Updates'

    def __str__(self):
        return '(updateShort (ID: 0x78d4dec1) = (update={}, date={}))'.format(str(self.update), str(self.date))



from ....tl.mtproto_request import MTProtoRequest


class ReorderPinnedDialogsRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.reorderPinnedDialogs#959ff644 flags:# force:flags.0?true order:Vector<InputPeer> = Bool"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x959ff644

    def __init__(self, order, force=None):
        """
        :param force: Telegram type: «true».
        :param order: Telegram type: «InputPeer». Must be a list.

        :returns Bool: This type has no constructors.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.force = force
        self.order = order

    def on_send(self, writer):
        writer.write_int(ReorderPinnedDialogsRequest.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.force else 0
        writer.write_int(flags)

        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.order))
        for order_item in self.order:
            order_item.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return ReorderPinnedDialogsRequest(None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'messages.reorderPinnedDialogs#959ff644 flags:# force:flags.0?true order:Vector<InputPeer> = Bool'

    def __str__(self):
        return '(messages.reorderPinnedDialogs (ID: 0x959ff644) = (force={}, order={}))'.format(str(self.force), None if not self.order else [str(_) for _ in self.order])



from ....tl.mtproto_request import MTProtoRequest


class ExportChatInviteRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.exportChatInvite#7d885289 chat_id:int = ExportedChatInvite"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x7d885289

    def __init__(self, chat_id):
        """
        :param chat_id: Telegram type: «int».

        :returns ExportedChatInvite: Instance of either ChatInviteEmpty, ChatInviteExported.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.chat_id = chat_id

    def on_send(self, writer):
        writer.write_int(ExportChatInviteRequest.constructor_id, signed=False)
        writer.write_int(self.chat_id)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return ExportChatInviteRequest(None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'messages.exportChatInvite#7d885289 chat_id:int = ExportedChatInvite'

    def __str__(self):
        return '(messages.exportChatInvite (ID: 0x7d885289) = (chat_id={}))'.format(str(self.chat_id))



from ....tl.mtproto_request import MTProtoRequest


class ValidatedRequestedInfo(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    payments.validatedRequestedInfo#d1451883 flags:# id:flags.0?string shipping_options:flags.1?Vector<ShippingOption> = payments.ValidatedRequestedInfo"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xd1451883

    def __init__(self, id=None, shipping_options=None):
        """
        :param id: Telegram type: «string».
        :param shipping_options: Telegram type: «ShippingOption». Must be a list.

        Constructor for payments.ValidatedRequestedInfo: Instance of ValidatedRequestedInfo.
        """
        super().__init__()

        self.id = id
        self.shipping_options = shipping_options

    def on_send(self, writer):
        writer.write_int(ValidatedRequestedInfo.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.id else 0
        flags |= (1 << 1) if self.shipping_options else 0
        writer.write_int(flags)

        if self.id:
            writer.tgwrite_string(self.id)

        if self.shipping_options:
            writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
            writer.write_int(len(self.shipping_options))
            for shipping_options_item in self.shipping_options:
                if shipping_options_item:
                    shipping_options_item.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return ValidatedRequestedInfo(None, None)

    def on_response(self, reader):
        flags = reader.read_int()

        if (flags & (1 << 0)) != 0:
            self.id = reader.tgread_string()

        if (flags & (1 << 1)) != 0:
            reader.read_int()  # Vector's constructor ID
            self.shipping_options = []  # Initialize an empty list
            shipping_options_len = reader.read_int()
            for _ in range(shipping_options_len):
                shipping_options_item = reader.tgread_object()
                self.shipping_options.append(shipping_options_item)

    def __repr__(self):
        return 'payments.validatedRequestedInfo#d1451883 flags:# id:flags.0?string shipping_options:flags.1?Vector<ShippingOption> = payments.ValidatedRequestedInfo'

    def __str__(self):
        return '(payments.validatedRequestedInfo (ID: 0xd1451883) = (id={}, shipping_options={}))'.format(str(self.id), None if not self.shipping_options else [str(_) for _ in self.shipping_options])



from ...tl.mtproto_request import MTProtoRequest


class GetFutureSaltsRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    get_future_salts#b921bd04 num:int = FutureSalts"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xb921bd04

    def __init__(self, num):
        """
        :param num: Telegram type: «int».

        :returns FutureSalts: Instance of FutureSalts.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.num = num

    def on_send(self, writer):
        writer.write_int(GetFutureSaltsRequest.constructor_id, signed=False)
        writer.write_int(self.num)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return GetFutureSaltsRequest(None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'get_future_salts#b921bd04 num:int = FutureSalts'

    def __str__(self):
        return '(get_future_salts (ID: 0xb921bd04) = (num={}))'.format(str(self.num))



from ....tl.mtproto_request import MTProtoRequest


class ForwardMessageRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.forwardMessage#33963bf9 peer:InputPeer id:int random_id:long = Updates"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x33963bf9

    def __init__(self, peer, id, random_id):
        """
        :param peer: Telegram type: «InputPeer».
        :param id: Telegram type: «int».
        :param random_id: Telegram type: «long».

        :returns Updates: Instance of either UpdatesTooLong, UpdateShortMessage, UpdateShortChatMessage, UpdateShort, UpdatesCombined, UpdatesTg, UpdateShortSentMessage.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.peer = peer
        self.id = id
        self.random_id = random_id

    def on_send(self, writer):
        writer.write_int(ForwardMessageRequest.constructor_id, signed=False)
        self.peer.on_send(writer)
        writer.write_int(self.id)
        writer.write_long(self.random_id)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return ForwardMessageRequest(None, None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'messages.forwardMessage#33963bf9 peer:InputPeer id:int random_id:long = Updates'

    def __str__(self):
        return '(messages.forwardMessage (ID: 0x33963bf9) = (peer={}, id={}, random_id={}))'.format(str(self.peer), str(self.id), str(self.random_id))
